/*
 * DigiTool.h
 * 
 * Copyright (c) 2011, Digimetrie. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301  USA
 */

#ifndef  DIGITOOL_H
#define  DIGITOOL_H
//+++++++++++++++++++++++++++++++++++++++++++++++


//--------------------------------------------------------------------------
/**
\file Digitool.h
Header contenant les dclarations des fonctions exposes par les Dlls digimtrie.
\n
\cond DOC_INTERNAL

\note modifications du	23/10/2001 : O.F.
\author stagiaire
\n
\n Modifications :
-# 07/08/2001: version originale (dernire modification)
-# 23/04/2003: Ajout de dfinition de nom de station : PCI_MICROLAB
-# 30/04/2003: \#define _export _declspec(dllexport) remplac par
	\n \#define _export __declspec(dllexport) pour compatibilit avec Borland
-# Au 30/04/2003: Listes complte de tous les numros de station
-# Au 14/05/2003: depart fichier O.F + ajout modification du stagiaire
-# + Ajout structure CF_CARTE + \#define trigger ananlogiques + modif Init_Conf
\n
\note modifications du	06/08/2003 :
-#  nouveau nom Digitoolusb.h pour gestion USB2 : 
-#  adaptation des define avec bit masq + elimination fonctions bas niveau pcilab
-#  mise  jour commentaires pour info client
\n
\note 03/12/2004 : ajout fonction set_id()
\note 10/05/2005 : ajout fonction Cread32()
\note 15/06/2006 : Ajout fonctions de bas niveau user gestion reseau USB_
\note 07/12/2006 : Ajout mise  jour define USB_TOR16 92 et define DT_TOR + USB_LAB_LP
\note 08_02_2007  : corrections numro d erreur
\note 11/04/2207  : ajout DT_AD_CPT
\note 26/11/2007  : Ajout parametre frequence dans fonction Ainfscan_buff()  
\note 04/11/2008 : version usblabr.dll modification version 1.0.0.0  VID + GUID  
\note 14/05/2009 : modification fonction get et set pleine echelle ad et da  
\note 17/12/2010 : Ajout de la X-macro DigiDefs_Cartes.def.h <-> D_CARTE_DIGI, et implmentation correspondante de Digi_GetCarte_Nom() et Digi_GetCarte_Dll()
                   Ajout de la X-macro DigiDefs_Errors.def.h <-> D_DIGI_ERR, et implmentation correspondante de Digi_GetErrorString()
                   Ajout de la X-macro DigiDefs_Events.def.h <-> D_DIGI_ERR, et implmentation correspondante de Digi_GetEventString()
\n

\note 14/04/2011 : Modification de la structure cf_Carte et de son utilisation :
	1 - Cette structure est cense dcrire les capacites fournies par un type de station. 
		Elle ne doit donc tre initialis qu'une fois, et jamais chang.
	2 - Ajout du champ gain_max.

\note 14/04/2011 : Ajout de la fonction BOut()
\note 15/04/2011 : Ajout de la fonction BIn()   // un peu ambigue comme nom....
\note 28/04/2011 : ajout fonctions Capt_ReadEep() et Capt_WriteEep() + correction textes


\warning Pour les dvelopeurs de Dlls Digimtrie, pour compiler il faudra un \#define DLL_CARTE_ID \<carte_ID\> o carte_ID est un identifiant de station parmi ceux dans "DigiDefs_Cartes.def.h"
// Ex : passer au compilateur -D DLL_CARTE_ID=DIGI_ZIGBEE



\todo  vrifier la documentation des fonctions de l'API
*/
/*! \endcond */ // DOC_INTERNAL

//--------------------------------------------------------------------------



//-----------------------------------------------
//-----------------------------------------------

#include <windows.h>


//||||||||||||||||||||||||||
//! \cond NEVER
//||||||||||||||||||||||||||

//--------------------------------------------------------------------------
// Macros Helpers pour les exportations des Dlls Digimtries
//--------------------------------------------------------------------------
#ifndef DOXYGEN
	#define _export __declspec(dllexport)
	#define PASCAL __stdcall

	#define PROTO_DECL( _type )	\
		typedef _type

	// ********* C PLUS PLUS ONLY **********
	#if defined(__cplusplus) || defined(c_plusplus)
		#ifndef DEXPORT
			#define DEXPORT( _type  )	\
				_export					\
				_type					\
				PASCAL
		#endif

		// For C functions (somes in Digitool.c)
		#define C_DECL_START		extern "C" {
		#define C_DECL_END			}
		#define DTYPE_C( _type )	extern "C" _type


	// ************ C ONLY *************
	#else
		#ifndef DEXPORT
			#define DEXPORT( _type  )	\
				_export					\
				_type					\
				PASCAL
		#endif

		// For C functions (somes in Digitool.c)
		#define DTYPE_C( _type ) _type

		#define C_DECL_START
		#define C_DECL_END
	#endif

	// %%%%%%%%% WINDOWS ONLY %%%%%%%%%%%%%
	#if defined(_WINDOWS) || defined(WIN32)
		#define DIGI_CALLBACK_U PASCAL  CALLBACK
		#define DIGI_CALLBACK_T( _type ) _type
		#define DIGI_CALLBACK( _type ) DIGI_CALLBACK_T(_type) DIGI_CALLBACK_U
	#else
		#error DIGI_CALLBACK not defined for this system
	#endif



	//--------------------------------------------------------------------------------------
	// COMMON TYPES
	#ifndef uint
		#define uint unsigned int
	#endif
	#ifndef BYTE
		#define BYTE unsigned char
	#endif
	#ifndef WORD
		#define WORD unsigned short
	#endif
	#ifndef DWORD
		#define DWORD unsigned long
	#endif
	#ifndef DDWORD
		typedef  unsigned __int64 DDWORD;
	#endif

	#ifdef UNICODE
		#define P_STR	LPCWSTR
	#else
		#define P_STR	LPCSTR
	#endif

	#ifndef __cplusplus
		typedef unsigned short bool;
	#endif

	// Le compilateur peur crire sans les Dlls, les noms de fonctions prfix avec '_' ou '?' ou etc...
	// Cette macro dcale le pointeur char* DLL_F_NAME et sa taille associe DLL_F_NAME__LEN aprs l'ventuel prfixe
	#define UNPREFIXE_DLL_FCT_NAME( DLL_F_NAME, DLL_F_NAME__LEN )		\
		if( DLL_F_NAME[0] == '_' || DLL_F_NAME[0] == '?' )		\
		{														\
			DLL_F_NAME++;										\
			DLL_F_NAME__LEN--;									\
		}


// -------- version DOXYGEN des macros -----------
#else

	#define PROTO_DECL( _type ) typedef _type
	#define DEXPORT( _type ) _type
	#define DTYPE_C( _type ) _type
	#define DIGI_CALLBACK_U
	#define DIGI_CALLBACK_T( _type ) _type
	#define DIGI_CALLBACK( _type ) _type

	#define C_DECL_START
	#define C_DECL_END
#endif 

//|||||||||||||||||||||||||||||
/*! \endcond */ // NEVER
//|||||||||||||||||||||||||||||






//--------------------------------------------------------------------------
/**
	\addtogroup API_group Interface de programmation (API) des stations \nom_des_cartes_supportees
	\par
		L'interface de programmation prsente ici permet de contrler les stations \e \nom_des_cartes_supportees
		depuis un programme crit en C/C++.

	\n

	\section sect_concepts Concepts prliminaires
	Certains arguments de fonctions sont incomprhensible sans l'explicitation de certains concepts.
	\n \ref pg_concepts "Explications ici"

	\n

	\section sect_DllCsts_Group Constantes lies  l'API
	Liste et descriptions des \ref Enum_Constants_Group utilises par l'API.

	\n

	\section sect_Dll_Structs Structures utilises par l'API
	Liste et descriptions des \ref Structs_group "structures" utilises par l'API.

	\n

	\section sect_ApiDll_Group  Fonctions de l'API
	\par
		Ces fonctions ont t rparties selon les catgories suivantes :
		- \ref CONTROL_group "Contrle" : information/intialisation/configuration de la station/Dll
		- \ref ACQUISITION_group "Acquisition" : rcupration des tensions/valeurs aux bornes des voies d'entres de la station
		- \ref RESTITUTION_group "Restitution" : fixation des tensions/valeurs aux bornes des voies de sorties de la 
			\if USE_GROUP_GENERATOR_COMPTEUR
		- \ref GENERATOR_COMPTEUR_group "Genrateurs/Compteurs" : gnrateurs de signals et/ou gestions des compteurs de la station
			\endif
			\if USE_POT
		- \ref Fcts_Pot_group "Potentiomtre" : calibrage et lectures du/des potentiomtre(s)
			\endif
			\if USE_GROUP_FCTS_CONVERSION
		- \ref FCTS_CONVERSION_group "Conversions" : lectures/critures des paramtres de conversion
			\endif
			\if USE_GROUP_TRIGGERS
		- \ref TRIGGERS_group "Dclencheurs" : contle des dclencheurs (triggers) d'acquisition et/ou de restitutions
			\endif
			\if USE_CAPTEUR
		- \ref CAPTEUR_group "Capteurs" : fonctions relatives aux ventuels capteurs de la station
			\endif
			\if USE_EVENTS
		- \ref Event_group "Evnements" : Gestion des venements gnrs par la Dll
			\endif
			\if USE_EEPROM
		- \ref EEPROM_group "EEPROM" : Lectures/Ecritures des donnes EEPROM de la station
			\endif
		- \ref Misc_group "Diverses" : fonctions atypiques de la Dll

	\n
	\n

	\section sect_OutDll_Group Fonctions hors Dll
	\par 
	Certaines fonctions n'ont pas t implment dans la Dll. 
	Elles sont implments dans les fichiers .c du rpertoire Digi_Commons (cf. \ref pg_fichiers "fichiers" )
	\n
	\par
	Si vous souhaitez utiliser l'une ou l'autre de ces fonctions, il faut ajouter le fichier .c correspondant dans
	votre projet.
	\par
	La description des fonctions des fonctions hors Dll vous signalera le fichier .c qui l'implmente.
	\par
	\ref OUTDLL_group "Liste des fonctions hors Dll"

	\see \ref sect_compilation_linking "compilation"
	
	\n
	\n

	@{
*/
//--------------------------------------------------------------------------






//! \cond NEVER
#ifndef DOXYGEN
#define  MAX_VOIES 32			//!< Maximum de voies gres par une station
#endif
/*! \endcond */ //NEVER


//##########################################################################
/**
	\addtogroup Structs_group Structures utilises par la Dll
	\ingroup API_group
		\par
			Sont listes et dtailles ici les structures utilises par certaines fonctions de l'API

		\n
		\n

	@{
*/
//##########################################################################
//-------------------------------------
//		Types utiliss par la Dll
//-------------------------------------



//! \brief Types de polarisations (cf. \ref sect_polarite "polarit" )
enum E_TYPE_POLARITE
{
	POLARITE_MONO = 0,	//!< Monopolaire
	POLARITE_BIPO = 1,	//!< Bipolaire
};


//! \brief Dcrit les utilisations possibles d'une voie digitale de la station
enum TOR_PORT_CONFIGURABILITY
{
	TOR_IN,			//!< Ne sait faire que du Digital In
	TOR_OUT,		//!< Ne sait faire que du Digital Out
	TOR_IN_OUT,		/*!< Peut faire Digital In et Out, mais pas en mme temps 
						\if USE_DINIT
							, utiliser #Dinit() pour changer de mode
						\endif
					*/
	TOR_IN_OUT_CO,	//!< Port en collecteur ouvert
};



#pragma pack (2)  //alignement des 2 structures sur 2 octets copatible Digiview



//---------------------------------------------------------------------
//! \brief Contient l'ensemble des capacites d'une station, et de certaines parties de son tat
typedef struct CF_CARTE
{
 	short         		slot;       			 //!< INUTILISE. Historiquement : numero de slot
    short         		no;         			 //!< Identifiant du type de station (parmi ceux dans Digitool.h ou DigiDefs_Cartes.def.h)
	unsigned short		adresse;    			 //!< Adresse de station (entre [0..(N-1)] o N est le nombre de station de type "no" prsent dans l'ordinateur)
	unsigned short		notpon;    				 //!< INUTILISE. Historiquement : numero de tampon



	//--------------------------------------------------------------
	//***** DMA ****
	//--------------------------------------------------------------

    unsigned short	   	masq_canal,    			 //!< INUTILISE. Historiquement :masque canal dma
    					n_dma,         			 //!< INUTILISE. Historiquement :no dma
    					ad_dmal,       			 //!< INUTILISE. Historiquement : adresse dma low
    					ad_dmah;       			 //!< INUTILISE. Historiquement : adresse dma high

    unsigned char     page_rh1					//!< INUTILISE. Historique...
					, ad_dmal1					//!< INUTILISE. Historique...
					, ad_dmah1					//!< INUTILISE. Historique...
					, page_rh2					//!< INUTILISE. Historique...
					, ad_dmal2					//!< INUTILISE. Historique...
					, ad_dmah2					//!< INUTILISE. Historique...
					;

    short		        disk;	       			//!<  INUTILISE. Historiquement : accs directe disque	 OUI/NON



    //--------------------------------------------------------------
    // *****  Voies en Entre Analogique
    //--------------------------------------------------------------

    short				  nvoies_ad;     			//!<  INUTILISE. Historiquement : voie ad de dpart
    short 				  adnumsize;     			//!<  INUTILISE. Historiquement : nombre de bits d'une acquisition analogique
    short 				  adnmaxvoies;   			//!<  Nombre de voies en entre analogique
    float                 adp_echelle;              /*!<  Intervalle positive de mesure en Volt. 
													      \n Exemple, si adp_echelle == 10, alors :
                                                          -# Si mode Bipolaire => mesures dans [-10V:10V]
                                                          -# Si mode Monopolaire mesures dans [0V;20V]
													*/

    short				  adpolarite[MAX_VOIES];    /*!<  Polarit des voies en entre analogique : 0 => Monopolaire, 1 => Bipolaire
														  \n Ex : si adpolarite[0] = 1 => la voie 0 est en mode bipolaire
														  \n Cf. enum E_TYPE_POLARITE.
													*/
    short                 addiff[MAX_VOIES];        //!<  INUTILISE. Historiquement : voies diffrentielles
    



    //--------------------------------------------------------------
    //*****  Voies en Sortie Analogique - DA
    //--------------------------------------------------------------

    short                 danmaxvoies;            //!<  Nombre de voies en sortie analogique
    float                 dap_echelle;            //!<  Valeurs maximum de la tension des voies analogiques en sortie. \n Exemple, si dap_echelle = 4 => Les voies en sorties auront une tension entre [-4V;4V]
	short				  danumsize;              //!<  INUTILISE. Historiquement : taille mot da
    short				  dapolarite[MAX_VOIES];    /*!<  Polarit des voies en sortie 
													analogique : 0 => Monopolaire, 1 => Bipolaire
														  \n Ex : si adpolarite[0] = 1 => la voie 0 est en mode bipolaire
														  \n Cf. enum E_TYPE_POLARITE.
													*/
    short                 dadiff[MAX_VOIES];      //!<  INUTILISE. Historiquement : voies diffrentielles




    //--------------------------------------------------------------
    //*****   Voies en sortie digitales - Tout Ou Rien - TOR
    //--------------------------------------------------------------

    USHORT				tormaxports,            //!<  Nombre max de ports TOR par composant (chaque port a 8 lignes binaires [0|1] )
    					tormaxcomp;             //!<  Nombre max de composants TOR \n Normalement == 1 \n pour compatibilite PIO-8255)
	short				torcomp;				//!<  INUTILSEE

	//! Nombre maximum de voies digitales
    #define NB_MAX_TORS  10

	//! \brief Configurabilit des port TOR (cf. #TOR_PORT_CONFIGURABILITY)
	/** \note ici, pas de numro de composant :  chaque composant de port TOR de la station est assign une srie de 3 octets de la structure
	       , et a que le composant ait ou pas 3 ports.
        \n Ainsi, au composant TOR numero Zero sont assignes les octets tconfig[0], tconfig[1] et tconfig[2]
        \n Et donc, la configurabilit de la voie 1 du composant 0 est donne par tconfig[1]
        \n Et finalement, la configurabilit de la ligne 3 de la voie 1, du composant 0 est donne par tconfig[1][3]
	*/
    WORD				tconfig[NB_MAX_TORS];	

	USHORT				tEtat;					//!< A usage de DigiView (si bit  1 la ligne est en OUT)
	USHORT				tVal;					//!< A usage de DigiView a un sens seulement si la ligne est en OUT, le bit donne la valeur




    //--------------------------------------------------------------
	//****    DIVERS
    //--------------------------------------------------------------

    short				timmaxcomp;             //!< Nombre d'horloges de ce type de station
    char            	nom[30];				//!< Nom humain de ce type de stations
    char				nom_dll[80];        	//!< Nom de la dll associe  ce type de station
	short		        no_ext;	       			//!< INUTILISE. Historiquement : n station d'extension : CENSE Disparaitres avec le multi carte
	char		   		nom_ext[30];  			//!< INUTILISE. Historiquement : nom ext : CENSE Disparaitres avec le multi carte
    short 				reserved;    			//!< RESERVE
    short 				ext_voiecon;            //!< INUTILISE. Historiquement : extexsion voie connect avec carte ad

    short 				trigv_ad;				/*!<  Numro de la voie en entre analogique qui est utilise par le mode trigger
													  \n Cf. les fonctions #SetTriggerAD() et #GetTriggerAD()
												*/
    short 				trigv_da;				//!< INUTILISE pour l'instant. FIXDOC
    short 				moyen;					//!< INUTILISE pour l'instant. FIXDOC
    float				trig_ad;                //!< Valeur seuil utilise par le mode trigger \n Voir les fonction SetTriggerAD() et GetTriggerAD()
    float				trig_da;                //!< trig DA
    short				t_trigger_ad;           //!< INUTILISE pour l'instant. Historiquement : type trigger ad 0= dvalid 1=montant 2= descendant
	short				t_trigger_da;			//!< INUTILISE pour l'instant. Historiquement : type trigger da 0= dvalid 1=montant 2= descendant
    short				f_buffer;               //!< INUTILISE. Historiquement : flag mode buffer circulaire
    short				trigv_tor;              //!< RESERVE
    unsigned long		buffer_sz;              //!< INTERNE : taille du buffer circulaire
	short				priorite;				//!< INTERNE : prorit thread d'acquisition asynchrone
    short				tgain;                  //!< INUTILISE. Historiquement : type gain AD Binaire  ou Dcimal

    USHORT gain_max;							//!< Valeur maximum pour les paramtres gains

    short free_0;								//!< reserv
    long				l8;                     //!< reserv
}
//! \cond NEVER
CF_CARTE;
/*! \endcond */



//-------------------------
//! \cond USE_CAPTEUR

//---------------------------------------------------------------------
//! \brief Description de l'tat d'un capteur.
typedef struct CAPT
{
	short	status;			//!< enum TCONV version DLL
	short	t_conv;			//!< type conversion 
	short   carte;			//!< LIBRE. Laiss  l'intention de l'utilisateur, en principe pour noter le numro de la station associe au capteur.
	short   voie;			//!< LIBRE. Laiss  l'intention de l'utilisateur, en principe pour noter le numro de la voie associe au capteur.
	float	gain;			//!< Gain utilis pour les <a href="group___event__group.html">conversions du capteur</a>.
	float	decalage;		//!< Dcalage utilis pour les <a href="group___event__group.html">conversions du capteur</a>.
	char	nom[16];		//!< LIBRE. Laiss  l'intention de l'utilisateur.
	char	grandeur[16];	//!< LIBRE. Laiss  l'intention de l'utilisateur.
	char	unite1[16];		//!< LIBRE. Laiss  l'intention de l'utilisateur.
	float **flist;			//!< INUTILISE, historiquement : pointeur sur liste de flottants linearisation
	short	n;				//!< INUTILISE, historiquement : n elements de la liste de flottants
	short	type;			//!< LIBRE. Laiss  l'intention de l'utilisateur.
	float	y1;				//!< INUTILISE, historiquement : point de mesure y1 servant  calculer les coefficients lineaires(pompiers
	float	y2;				//!< INUTILISE, historiquement : point de mesure y2 servant  calculer les coefficients lineaires(pompiers
} 
  CAPT  //!< struct #CAPT
,*PCAPT //!< Pointeur sur #CAPT
;

/*! \endcond */ //USE_CAPTEUR
//-------------------------




#pragma pack ()


//##########################################################################
/*! @}*/ // Fin de Structs_group
//##########################################################################









//##########################################################################
/**
	\addtogroup CONTROL_group Fonctions de contrle de la station.
	\ingroup API_group

	\par
	Sont listes ici, les fonctions permettant de :
		- lire certains paramtres de la station
		- changer certains paramtres de la station
		- intialiser/rinitialiser la station

	\n
	\n

	@{
*/
//##########################################################################


  

//---------------------------------------------------------------------------------------
//! \brief Lecture du numero de version de la DLL
/**
	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Digitool_rev(
				UCHAR *rev //!< OUT: numro de version de 0  255
			 );


//--------------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Digitool_rev)(
					UCHAR *rev
				);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Digitool_rev		pf_Digitool_rev;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//--------------------






//-------------------------
//! \cond USE_TARGET_REV
//---------------------------------------------------------------------------------------
//! \brief lecture du numero de version du moniteur (firmware) embarqu dans la station */
/**
	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Target_rev (
				  UCHAR  *rev		//!< OUT: numro du firmware de 0  255
				, USHORT carte		//!< \arg_carteType_Def
				, USHORT adresse	//!< \arg_carteNum_Def
			); 

//--------------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Target_rev)(
					  UCHAR  *rev		
					, USHORT carte		
					, USHORT adresse	
				);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Target_rev		pf_Target_rev;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//--------------------
/*! \endcond */ // USE_TARGET_REV
//-------------------------




//------------------------------------------------------------
//! \brief Rcupration des capacits de la station
/**
	\param pcf_carte : OUT : contiendra les donnes de la station (doit pointer sur une zone mmoire valide)

	\return \ret_error_Def
*/
//-----------
C_DECL_START
//-----------
DEXPORT(short)
Get_Conf( CF_CARTE* pcf_carte  );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)			
(PASCAL *PROTO_Get_Conf)( CF_CARTE* pcf_carte);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Get_Conf	pf_Get_Conf;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END






//-------------------------------------------
C_DECL_START
//---------------------------------------------------------------------------------------
/*! \if RESET_CHAUD_FROID
		\brief Reset chaud ou froid d'une ou de toutes les stations
	\else
		\brief Reseter une station
	\endif

*/
/**
	\param mode    : 
		\if RESET_CHAUD_FROID
			Si (mode & 0x1) == Reset Chaud : ne pas rescanner ni reseter toutes les stations de type \a station prsentes
		\else
			FIXDOC
		\endif

	\param exts    : 
		\if PCILAB
			\warning ULONG dans PCILAB!!!
		\else
			\arg_unused_ext
		\endif

	\param carte   : \arg_carteType_Def
	\param adresse : \arg_carteNum_Def

	\return \ret_error_Def
*/
//-----------
DEXPORT(SHORT)
Reset_carte(   
			   USHORT mode
			 #ifndef PCILAB
			 , USHORT exts
			 #else
			 , ULONG exts
			 #endif
			 , USHORT carte
			 , USHORT adresse
			 );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Reset_carte)(
			   USHORT mode
			 , USHORT exts
			 , USHORT carte
			 , USHORT adresse
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Reset_carte	pf_Reset_carte;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END




//-----------------
//! \cond USE_DINIT
//-------------------------------------------
//! \brief Paramtrage d'une voie en mode Digital|Analogique, IN|OUT
/**
	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Dinit(		
			  USHORT portx        //!< \arg_Num_Voie_Digit_Carte_Solo_Def
			, USHORT mode         //!< 0 => configurer la voie en entre, sinon en sortie
			, USHORT no_composant //!< \arg_composantDigital_Def
			, USHORT carte        //!< \arg_carteType_Def
			, USHORT adresse      //!< \arg_carteNum_Def
			);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
( PASCAL *PROTO_Dinit)(
			USHORT portx,        
			USHORT mode,         
			USHORT no_composant, 
			USHORT carte,        
			USHORT adresse       
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Dinit	pf_Dinit;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END
/*! \endcond */ // USE_DINIT
//--------------------------




//---------------------------------------------------------------------------------------
//! \brief Retourne le nombre de stations du type demand, dtectes dans le systme
/**
	\return Le nombre de carte du type spcifi dtectes par la Dll
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(WORD)
Get_Nb_Cartes( 
					  WORD carte	//!< Type de carte  rechercher
			);


//--------------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(WORD)
(PASCAL *PROTO_Get_Nb_Cartes)(
							  WORD carte	
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Get_Nb_Cartes	pf_Get_Nb_Cartes;
/*! \endcond */ // NEVER
//--------------------

C_DECL_END
//--------------------



//------------------
//! \cond DOC_INTERNAL
//---------------------------------------------------------------------------------------
//---------------------------------------------------------------------------------------
// fonctions a developper ......... incluses dans pcilab
//! FIXDOC
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
GetDeviceNumber( 
					   ULONG *deviceNumber
					 , ULONG exts
					 , USHORT carte
				 );

//--------------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_GetDeviceNumber)(
						   ULONG *deviceNumber
						 , ULONG exts
						 , USHORT carte
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_GetDeviceNumber		pf_GetDeviceNumber;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//--------------------
/*! \endcond */ // DOC_INTERNAL
//--------------------



//---------------------------
//! \cond USE_WATCHDOG

//---------------------------------------------------------------------------------------
//! \brief Arret du chien de garde logiciel									
/**
	Cette fonction dvalide le watchdog et remet  zro le drapeau panne de la station
	et le relais assoc sortie

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Stop_wdg(
			  USHORT ext		//!< \arg_unused
			, USHORT carte		//!< \arg_carteType_Def
            , USHORT adresse	//!< \arg_carteNum_Def
		);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Stop_wdg)(
					  USHORT ext		
					, USHORT carte		
					, USHORT adresse	
				);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Stop_wdg		pf_Stop_wdg;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//--------------------

/*! \endcond */ // USE_WATCHDOG
//---------------------------


//##########################################################################
/*! @}*/ // Fin de CONTROL_group
//##########################################################################















//##########################################################################
/**
	\addtogroup ACQUISITION_group Fonctions d'acquisitions
	\ingroup API_group

	\par
	Sont regroups ici les fonctions permettant de rcuprer des mesures de la station.
	\par
	Les mesures se font sur les voie en entre de la station qui peuvent tre de type
		- Analogique : mesure de tensions
		- Digitale   : mesure d'tats d'un groupe de lignes binaires
	\n Pour connaitre le nombre et les caractritiques des voies analogiques et digitales gres par la station, 
	veuillez vous rfrer  sa doc technique.
	\par
	Ce document liste toutes les fonctions de lectures, mme les plus sothriques.
	\par
	Mais les fonctions les plus courament utilises sont:
			\if USE_BIN_FCTS
		- #BIn()  : lecture d'une ligne binaire (ie. appartenant  une voie digitale)
			\endif
		- #Din()  : lecture d'un groupe de ligne digitale
		- #Ainf() : lecture d'une ligne analogique
	\par
	Et leurs fonctions complmentaires permettant de faire des mesures en rafale : #Dinscan, #Ainfscan(), ...
	\par
	Deux modes de mesures sont possibles :
		- mode synchrone : un seul appel de fonction suffit, qui ne retourne que lorsque les mesures demandes sont arrives
		- mode asynchrone : plusieurs appels de fonctions sont ncessaires pour obtenir les mesures. Voir: \ref concept_asynchrone

	\n
	\n

	@{
*/
//##########################################################################

//---------------------------------------------------------------------------------------
//! \brief Lit la valeur d'un des port digitaux de la carte
/*
    Un port digital contient en gnral 8 lignes binaires
    La valeur de \a data donne l'tat voulue pour chacune de ces lignes binaires
    en suivant la rgle: 
		-# data[0] == tat voulu pour la ligne 0
		-# data[1] == tat voulu pour la ligne 1
		-# etc...
	\if COLL_OUVERT
		\warning Les ports de ce type de station sont en collecteur ouvert
	\else
		\if USE_DINIT
			\warning Certaines carte ncessitent que le port digitaux ait t prcdement configur en lecture avec #DInit()
		\endif
	\endif

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Din(		
			  USHORT *data			//!< OUT : pointeur de stockage de la donne lue 
			, USHORT portx			//!< \arg_Num_Voie_Digit_Carte_Solo_Def
			, USHORT no_composant	//!< \arg_composantDigital_Def
			, USHORT carte			//!< \arg_carteType_Def
			, USHORT adresse		//!< \arg_carteNum_Def
			);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
( PASCAL *PROTO_Din)(
			  USHORT *data
			, USHORT portx
			, USHORT no_composant
			, USHORT carte
			, USHORT adresse
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Din pf_Din;
/*! \endcond */ // NEVER
//-----------
C_DECL_END




//---------------------------------------------------------------------------------------
//! \brief Effectuer des chantillonages digitaux massifs et rguliers
/*
	FIXDOC
		\if USE_DINIT
	\warning le port doit avoir t configurer en mode IN avec un appel prcdent  #Dinit()
		\endif USE_DINIT

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Dinscan(	
			  USHORT port_tampon	//!< \arg_VoieTampon_IN_Def
			, USHORT port			//!< \arg_VoieCarte_IN_Def
			, USHORT n_ports_max	//!< \arg_TamponNbVoie_Def
			, USHORT n_ports		//!< \arg_NbVoieCarte_IN_Def
			, USHORT no_composant	//!< \arg_composantDigital_Def
			, ULONG  n_val			//!< \arg_nb_Samples_IN 
			, ULONG  *frequence		//!< \arg_freq_IN
			, USHORT mode			//!< mode de configuration generateur interne
			, UCHAR  *tampon		//!< \arg_Tampon_IN_Def
			, ULONG  ext			//!< \arg_unused_ext
			, USHORT carte			//!< \arg_carteType_Def
			, USHORT adresse		//!< \arg_carteNum_Def
			);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Dinscan)(
				  USHORT port_tampon  
				, USHORT port         
				, USHORT n_ports_max  
				, USHORT n_ports      
				, USHORT no_composant 
				, ULONG  n_val         
				, ULONG  *frequence    
				, USHORT mode         
				, UCHAR  *tampon 
				, ULONG  ext           
				, USHORT carte        
				, USHORT adresse      
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Dinscan		pf_Dinscan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END




//! \cond USE_BIN_FCTS
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
//! \brief Lit l'tat d'une seule ligne d'un port Digital
/**
	\return \ret_error_Def
*/
DEXPORT(SHORT)
BIn(		
		  USHORT *data		  //!< OUT : Etat lu de la ligne (0 ou 1)
		, USHORT num_ligne    //!< \arg_num_ligne
		, USHORT portx        //!< \arg_Num_Voie_Digit_Carte_Solo_Def
		, USHORT no_composant //!< \arg_composantDigital_Def
		, USHORT carte        //!< \arg_carteType_Def
		, USHORT adresse      //!< \arg_carteNum_Def
	);


//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_BIn)(
				  USHORT *data		  
				, USHORT num_ligne    
				, USHORT portx        
				, USHORT no_composant 
				, USHORT carte        
				, USHORT adresse      
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_BIn		pf_BIn;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END
/*! \endcond */ // USE_BIN_FCTS
//--------------------------




//---------------------------------------------------------------------------------------
//! \brief Effectuer une et une seule lecture d'une des voies d'entre Analogique
/**
 \warning Cette fonction est l uniquement pour compatibilit, prfrez l'utilisation de #Ainf()
 \warning Cette fonction retourne dans \a data la valeur brute lue sur la voie spcifie, cette valeur N'est PAS la tension de la voie.
	\n Pour avoir un conversion automatique en tension, voir la fonction #Ainf()

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Ain(
	  USHORT *data		//!< OUT : Valeur lue (brute, non signe, sans conversion en Volt)
	, USHORT voie       //!< \arg_Num_Voie_Anal_Carte_Solo_Def
	, USHORT gain       //!< \arg_Gain_Solo
	, USHORT mode       /*!< Drapeau de configuration du mode d'acquisition :
								- voir #DT_AD_ENTREE
								- voir #DT_AD_VOIE
						*/
	, ULONG  exts       //!< \arg_unused_ext
	, USHORT carte      //!< \arg_carteType_Def
	, USHORT adresse    //!< \arg_carteNum_Def
    );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(__stdcall  *PROTO_Ain)(
					  USHORT *data  
					, USHORT voie        
					, USHORT gain        
					, USHORT mode        
					, ULONG  exts         
					, USHORT carte       
					, USHORT adresse     
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ain		pf_Ain;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//----------------------
// NON DOCUMENTEE
//! \cond NEVER
//---------------------------------------------------------------------------------------
//! \brief NON DOCUMENTEE
/**
	\return \ret_error_Def
*/
C_DECL_START
//-----------
DEXPORT(short)
Ainv(
		  WORD  *tampon   		//!< \arg_Tampon_IN_Def
		, WORD  voie           	//!< \arg_VoieCarte_IN_Def
		, WORD  n_voies        	//!< \arg_NbVoieCarte_IN_Def
		, WORD  gain[]    		//!< \arg_TabGain
		, WORD  mode           	//!< mode de configuration generateur interne + dclenchement 
		, ULONG exts          	//!< \arg_unused_ext
		, WORD  carte          	//!< \arg_carteType_Def
		, WORD  adresse		  	//!< \arg_carteNum_Def
    );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Ainv)(
				  WORD  *tampon   
				, WORD  voie           
				, WORD  n_voies        
				, WORD  gain[]    
				, WORD  mode           
				, ULONG exts          
				, WORD  carte          
				, WORD  adresse		  
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ainv	pf_Ainv;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END
//-----------
/*! \endcond */ // NEVER // NON DOCUMENTEE
//-----------------------------------------



//---------------------------------------------------------------------------------------
//! \brief Effectuer une et une seule lecture d'une des voies d'entre Analogique
/**
	\n Cette fonction retourne dans \a fdata la tension lue aux bornes de la voie spcifie.
	\if NEED_RESET_AT_INIT
		\note Certaines cartes ncessitent avant de pouvoir utiliser cette fonction d'avoir effectu un appel  #Reset_carte() (un seul appel  cette fonction suffit).
	\endif
	\if NEED_SET_ECHELLE_AT_INIT
		\note Certaines cartes ncessitent pour que les conversion en tension soit ralises correctement
				de pralablement configurer l'chelle avec un appel  #SetPleineEchelleAD().
	\endif

	\return \ret_error_Def
*/
C_DECL_START
//-----------
DEXPORT(SHORT)
Ainf(
		  float *fdata		//!< OUT : Valeur en Volt lue sur la voie
		, USHORT voie       //!< \arg_Num_Voie_Anal_Carte_Solo_Def
		, USHORT gain       //!< \arg_Gain_Solo
		, USHORT mode       /*!< Drapeau de configuration du mode d'acquisition :
									- mode & DT_AD_VOIE   : TRUE => simple, FALSE => Acquisition en mode diffrentiel
							*/
		, ULONG  exts       //! \arg_unused_ext
		, USHORT carte      //!< \arg_carteType_Def
		, USHORT adresse    //!< \arg_carteNum_Def
	);


//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Ainf)(
				  float *fdata		 
				, USHORT voie        
				, USHORT gain        
				, USHORT mode        
				, ULONG exts         
				, USHORT carte       
				, USHORT adresse     
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ainf	pf_Ainf;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END






//----------------------
// NON DOCUMENTEE
//! \cond NEVER
//---------------------------------------------------------------------------------------
//! \brief NON DOCUMENTEE
/**
	\return \ret_error_Def
*/
C_DECL_START
//-----------
DEXPORT(SHORT)
Ainfv(
		  FLOAT *tampon			//!<  \arg_Tampon_IN_Def
		, WORD  voie			//!<  \arg_VoieCarte_IN_Def
		, WORD  n_voies			//!<  \arg_NbVoieCarte_IN_Def
		, WORD  gain[]			//!<  \arg_TabGain
		, WORD  mode			//!<  mode de configuration generateur interne + dclenchement 
		, ULONG exts			//!<  \arg_unused_ext
		, WORD  carte			//!<  \arg_carteType_Def
		, WORD  adresse			//!<  \arg_carteNum_Def
	);


//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Ainfv)(
				  FLOAT *tampon		  
				, WORD  voie           
				, WORD  n_voies        
				, WORD  gain[]    
				, WORD  mode           
				, ULONG exts          
				, WORD  carte          
				, WORD  adresse        
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ainfv	pf_Ainfv;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END
//-----------
/*! \endcond */ // NEVER // NON DOCUMENTEE
//-----------------------------------------




    
//---------------------------------------------------------------------------------------
//! \brief Effectuer des acquisitions continues  une frquence donne sur un groupe de voies en entre analogique
/**
	\n Cette fonction est similaire  #Ainfscan(), sauf qu'elle n'effectue pas les conversions en tension.
	\n Aussi il est conseill d'utiliser de prfrerence #Ainfscan().
	\n
	\n Veuillez vous reportez  la documentation de #Ainfscan() pour des explications dtaills sur les paramtres.

	\param voie_tampon	:  \arg_VoieTampon_IN_Def
	\param voie_carte	:  \arg_VoieCarte_IN_Def
	\param n_voies_tampon	:  \arg_TamponNbVoie_Def
	\param n_voies		:  \arg_NbVoieCarte_IN_Def
	\param gain 		:  \arg_TabGain
	\param n_val		:  \arg_nb_Samples_IN 
	\param frequence	:  \arg_freq_IN
	\param mode			:  \arg_mode_IN
							\if SCAN_REQUIERT_DT_AD_TIM
								\n REQUIS : (mode & #DT_AD_TIM) == 1
							\endif

	\param tampon		:  \arg_Tampon_IN_Def
	\param exts			:   \if USE_ACQU_THREAD_PRIO
								\arg_ext_as_ThreadPrio
							\else
								\arg_unused_ext
							\endif
	\param carte 		:  \arg_carteType_Def
	\param adresse		:  \arg_carteNum_Def

	\return \ret_error_Def
*/
C_DECL_START
//-----------
DEXPORT(SHORT)
Ainscan(
			  USHORT voie_tampon
			, USHORT voie_carte
			, USHORT n_voies_tampon
			, USHORT n_voies
			, USHORT gain[]
			, ULONG  n_val
			, ULONG  *frequence
			, USHORT mode
			, USHORT *tampon
			, ULONG  exts
			, USHORT carte
			, USHORT adresse
	);


//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Ainscan)(
					  USHORT voie_tampon	
					, USHORT voie			
					, USHORT n_voies_max	
					, USHORT n_voies		
					, USHORT gain[]			
					, ULONG  n_val			
					, ULONG  *frequence		
					, USHORT mode			
					, USHORT *tampon		
					, ULONG  exts			
					, USHORT carte 			
					, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ainscan		pf_Ainscan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END





//---------------------------------------------------------------------------------------
//! \brief Lecture asynchrone de mesures (sans conversions en tension)
/**
	\n Cette fonction est similaire  #Ainfscan_buff(), sauf qu'elle n'effectue pas les conversions en tension.
	\n Aussi il est conseill d'utiliser de prfrerence #Ainfscan()/#Ainfscan_buff.
	\n 
	\n Pour des explications dtailles sur les paramtres de cette fonction, reportez-vous  #Ainfscan_buff().

	\warning l'appel  cette fonction doit faire suite  un appel  Ainscan() avec mode \ref concept_asynchrone "asynchrone".
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Ainscan_buff(
				  WORD		*Buffer		//!< \arg_buffer_buff_IN
				, ULONG		*nb_val		//!< \arg_nb_val_buff_IN
				, WORD		*stop		//!< \arg_stop_buff
				, ULONG		timeout		//!< \arg_timeout_buff
				, WORD		carte 		//!< \arg_carteType_Def
				, WORD		adresse		//!< \arg_carteNum_Def		      
    );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Ainscan_buff)(
				  WORD		*Buffer		
				, ULONG		*nb_val		
				, WORD		*stop		
				, ULONG		timeout		
				, WORD		carte 		
				, WORD		adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ainscan_buff		pf_Ainscan_buff;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END





//---------------------------------------------------------------------------------------
//! \brief Effectuer des acquisitions continues  une frquence donne sur un groupe de voies en entre analogique
/**
	\n La rcupration des donnes peut-tre en mode \ref concept_asynchrone "synchrone ou asynchrone" (voir \ref Enum_Constants_Group ).

		\if USE_GROUP_TRIGGERS
	\n Le dbut des mesures peut-tre immdiat ou bien \ref concept_trigger "dclench" (voir \ref Enum_Constants_Group ).
	\n Si le mode "dclencheur" est utilis, la fonction ne retournera pas avant le dclenchement, que le mode
	asynchrone ait t spcifi ou pas.
		\endif

	\param voie_tampon	:  \arg_VoieTampon_IN_Def
	\param voie_carte	:  \arg_VoieCarte_IN_Def
	\param n_voies_tampon	:  \arg_TamponNbVoie_Def
	\param n_voies		:  \arg_NbVoieCarte_IN_Def
	\param gain 		:  \arg_TabGain
	\param n_val		:  \arg_nb_Samples_IN 
	\param frequence	:  \arg_freq_IN
	\param mode			:  \arg_mode_IN
							\if SCAN_REQUIERT_DT_AD_TIM
								\n REQUIS : (mode & #DT_AD_TIM) == 1
							\endif
	\param tampon		:  \arg_Tampon_IN_Def
	\param exts			:   \if USE_ACQU_THREAD_PRIO
								\arg_ext_as_ThreadPrio
							\else
								\arg_unused_ext
							\endif
	\param carte 		:  \arg_carteType_Def
	\param adresse		:  \arg_carteNum_Def

	\return \ret_error_Def

	\n
	\n

	Exemple d'utilisation :
	\code
	USHORT gain[16];
	gain[3] = 0; // Pas de gain pour la voie 3
	gain[4] = 0; // Pas de gain pour la voie 4
	gain[5] = 2; // gain de 2 pour la voie 5
	gain[6] = 1; // gain de 1 pour la voie 6
	float tampon[400];

	short err_code = Ainfscan( 
					  2               // Remplir le tampon  partir de sa voie 2
					, 3               // 1ere voie de l'intervalle de voies  scanner 
					, 10              // le tampon contient 10 voies
					, 4               // Intervalle de 4 voies  scanner => puisque la 1ere voie est la n 3 => intervalle  scanner == [3,4,5,6]
					, gain            // Gain pour les voies
					, 30              // 30 mesures  faire
					, (DT_AD_TRGIH|DT_AD_ENTREE) // dclenchement par front montant ET voies en mode bipolaire
					, &tampon         // le tampon, de taille au moins (10 * 30)
					, 0
					, USB_NANOLABH    // la carte est de type Nanolab /H
					, 0               // 1ere carte nanolab/H repr par le systme d'exploitation
					);
	\endcode

	\see \ref concept_tampon, \ref concept_asynchrone, \ref concept_conversion 
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Ainfscan(
			  USHORT voie_tampon
			, USHORT voie_carte
			, USHORT n_voies_tampon
			, USHORT n_voies
			, USHORT gain[]
			, ULONG  n_val
			, ULONG  *frequence
			, USHORT mode
			, float  *tampon
			, ULONG  exts
			, USHORT carte
			, USHORT adresse
		);


//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Ainfscan)(
				  USHORT voie_tampon	
				, USHORT voie			
				, USHORT n_voies_max	
				, USHORT n_voies		
				, USHORT gain[]		
				, ULONG  n_val			
				, ULONG  *frequence		
				, USHORT mode			
				, float  *tampon		
				, ULONG  exts			
				, USHORT carte 			
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ainfscan		pf_Ainfscan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END






//---------------------------------------------------------------------------------------
//! \brief Lecture asynchrone de mesures
/** \n
		\param voie_carte		: \arg_VoieCarte_IN_Def
		\param n_voies_carte	: \arg_NbVoieCarte_IN_Def
		\param gain[]			: Mme tableau que celui pass lors de l'appel  #Ainfscan()
		\param *buffer			: \arg_buffer_buff_IN
		\param *nb_val			: \arg_nb_val_buff_IN
		\param *frequence		: IN : mme valeur que celle pass lors de l'appel  #Ainfscan()
		\param *stop			: \arg_stop_buff
		\param timeout			: \arg_timeout_buff
		\param carte            : \arg_carteType_Def
		\param adresse          : \arg_carteNum_Def

	\return \ret_error_Def

	\warning l'appel  cette fonction doit faire suite  un appel  Ainfscan() avec mode \ref concept_asynchrone "asynchrone".
	
	Cette fonction rcuperera jusqu' \a *nb_val chantillons disponibles.
	\n 
	\n Le concept de tampon n'est pas utilis par cette fonction, le tableau \a buffer (qui doit tre prallou par l'utilisateur)
	sera remplit squentiellement jusqu' :
	    - que \a *nb_val soit atteint
	    - que le dlai spcifi par \a timeout soit coul

	\see \ref concept_asynchrone, \ref concept_conversion 
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Ainfscan_buff( 
				  WORD	voie_carte
				, WORD	n_voies_carte
				, WORD	gain[]
				, float *buffer
				, ULONG *nb_val
				, ULONG *frequence
				, WORD	*stop
				, ULONG timeout
				, WORD  carte
				, WORD  adresse
		);


//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Ainfscan_buff)(
				  WORD	voie		
				, WORD	n_voies		
				, WORD	gain[]		
				, float *Buffer		
				, ULONG *nb_val		
									
				, ULONG *frequence  
				, WORD	*_stop		
				, ULONG timeout
				, WORD  carte 		
				, WORD  adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ainfscan_buff		pf_Ainfscan_buff;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//%%%%%%%%%%%%%%%%%%%
//! \cond DO_MULTISCAN
//%%%%%%%%%%%%%%%%%%%

//---------------------------------------------------------------------------------------
//! \brief Effectuer des acquisitions continues  une frquence donne sur un groupe de voies htrognes (sans conversion en tension)
/**
	\n Cette fonction est similaire  #Multifscan(), except qu'elle ne convertit pas les rsultat en tension.
	\n Veuillez utilisez de prfrence #Multifscan().
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Multiscan(
			  WORD  voie_tampon		//!<  \arg_VoieTampon_IN_Def
			, WORD  voie_carte		//!<  \arg_VoieCarte_IN_Def
			, WORD  n_voies_max		//!<  \arg_TamponNbVoie_Def 
			, WORD  n_voies			//!<  \arg_NbVoieCarte_IN_Def + 2 pour [port din + timer1]
			, WORD  gain[]			//!<  \arg_TabGain  
			, ULONG n_val			//!<  \arg_nb_Samples_IN 
			, ULONG *frequence		//!<  \arg_freq_IN
			, WORD  mode			/*!<  \arg_mode_IN
												\if SCAN_REQUIERT_DT_AD_TIM
													\n REQUIS : (mode & #DT_AD_TIM) == 1
												\endif
									*/
			, WORD  *tampon			//!<  \arg_Tampon_IN_Def 
			, ULONG exts			/*!<	\if USE_ACQU_THREAD_PRIO
												\arg_ext_as_ThreadPrio
											\else
												\arg_unused_ext
											\endif
									*/
			, WORD  carte 			//!<  \arg_carteType_Def 
			, WORD  adresse			//!<  \arg_carteNum_Def      
    );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Multiscan)(
					  WORD  voie_tampon		
					, WORD  voie			
					, WORD  n_voies_max		
					, WORD  n_voies			
					, WORD  gain[]			
					, ULONG n_val			
					, ULONG *frequence		
					, WORD  mode			
					, WORD  *tampon			
					, ULONG exts			
					, WORD  carte 			
					, WORD  adresse			
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Multiscan		pf_Multiscan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! \brief Lecture asynchrone de mesures htrognes (sans conversion en tension)
/**
	\n Cette fonction est similaire  #Ainfscan_buff(), sauf qu'elle a une utilisation plus particulire et plus rare(cf. #Multifscan()).
	\n 
	\n Pour des explications dtailles sur les paramtres de cette fonction, reportez-vous  #Ainfscan_buff().

	\warning l'appel  cette fonction doit faire suite  un appel  Multiscan() avec mode \ref concept_asynchrone "asynchrone".
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Multiscan_buff(
				  WORD  *Buffer		//!< \arg_buffer_buff_IN
				, ULONG *nb_val		//!< \arg_nb_val_buff_IN
				, WORD  *stop		//!< \arg_stop_buff
				, ULONG timeout		//!< \arg_timeout_buff
				, WORD  carte 		//!< \arg_carteType_Def
				, WORD	adresse		//!< \arg_carteNum_Def	         
			);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Multiscan_buff)(
						  WORD  *Buffer		
						, ULONG *nb_val		
						, WORD  *stop		
						, ULONG timeout		
						, WORD  carte 		
						, WORD	adresse		
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Multiscan_buff		pf_Multiscan_buff;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//------------------








//---------------------------------------------------------------------------------------
//! \brief Effectuer des acquisitions continues  une frquence donne sur un groupe de voies htrognes
/**
	\warning Cette fonction n'est pas documente correctement, car pour l'instant peu utilise.
	\n Si vous tes certain d'en avoir besoin, contacter nous.

	\n Elle ressemble  la fonction #Ainfscan(),  la diffrence qu'elle effectue des chantillonages htrognes, 
		retourns dans le tampon dans cet ordre :
		- les voies analogiques en entre : intervalle spcifie comme dans #Ainfscan() sauf que le nombre de voies vaut : \a n_voies - 2 (en mode non diffrentiel)
		- une voie numrique
		- une voie de comptage

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Multifscan(
			  WORD  voie_tampon		//!<  \arg_VoieTampon_IN_Def
			, WORD  voie_carte		//!<  \arg_VoieCarte_IN_Def
			, WORD  taille_tampon	//!<  \arg_TamponNbVoie_Def
			, WORD  n_voies			//!<  \arg_NbVoieCarte_IN_Def + 2 pour [port din + timer1]
			, WORD  gain[]			//!<  \arg_TabGain
			, ULONG n_val			//!<  \arg_nb_Samples_IN 
			, ULONG *frequence		//!<  \arg_freq_IN
			, WORD  mode			/*!<  \arg_mode_IN
												\if SCAN_REQUIERT_DT_AD_TIM
													\n REQUIS : (mode & #DT_AD_TIM) == 1
												\endif
									*/
			, float  *tampon		//!<  \arg_Tampon_IN_Def
			, ULONG exts			/*!<	\if USE_ACQU_THREAD_PRIO
												\arg_ext_as_ThreadPrio
											\else
												\arg_unused_ext
											\endif
									*/
			, WORD  carte 			//!<  \arg_carteType_Def
			, WORD  adresse			//!<  \arg_carteNum_Def
    );

//------------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Multifscan)(
					  WORD  voie_tampon		
					, WORD  voie			
					, WORD  n_voies_max		
					, WORD  n_voies			
					, WORD  gain[]			
					, ULONG n_val			
					, ULONG *frequence		
					, WORD  mode			
					, float  *tampon			
					, ULONG exts			
					, WORD  carte 			
					, WORD  adresse			
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Multifscan		pf_Multifscan;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//------------------








//---------------------------------------------------------------------------------------
//! \brief Lecture asynchrone de mesures htrognes
/**
	\n Cette fonction est similaire  #Ainfscan_buff(), sauf qu'elle a une utilisation plus particulire et plus rare (cf. #Multifscan()).
	\n 
	\n Pour des explications dtailles sur les paramtres de cette fonction, reportez-vous  #Ainfscan_buff().

	\warning l'appel  cette fonction doit faire suite  un appel  Multifscan() avec mode \ref concept_asynchrone "asynchrone".
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Multifscan_buff(
				  WORD  dummy		//!< IMPORTANT : doit toujours valoir 0
				, WORD  n_voies		//!< Doit correspondre  la valeur du paramtre \a n_voies pass prcdement  #Multifscan()
				, WORD  gain[]		//!< Mme tableau que celui pass lors de l'appel  #Multifscan()
				, float *buffer		//!< \arg_buffer_buff_IN
				, ULONG *nb_val		//!< \arg_nb_val_buff_IN
				, ULONG	*frequence	//!< IN : mme valeur que celle pass lors de l'appel  #Multifscan()
				, WORD	*stop		//!< \arg_stop_buff
				, ULONG timeout		//!< \arg_timeout_buff
				, WORD  carte 		//!< \arg_carteType_Def
				, WORD	adresse		//!< \arg_carteNum_Def	         
			);


//------------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Multifscan_buff)(
						  WORD voie         	
						, WORD n_voies      
						, WORD  gain[]		
						, float  *Buffer	
						, ULONG *nb_val	
						, ULONG	*frequence 
						, WORD  *stop		
						, ULONG timeout		
						, WORD  carte 		
						, WORD	adresse		
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Multifscan_buff		pf_Multifscan_buff;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//------------------

//%%%%%%%%%%%%%%%%%%%
/*! \endcond */ // DO_MULTISCAN
//%%%%%%%%%%%%%%%%%%%




//---------------------------------------------------------------------------------------
//! \brief Retourne le nombre d'echantillons disponibles pour lecture asynchrone
/**
	\n
	Les fonctions de type ??scan() (par ex. #Ainfscan() )
	en activant le mode \ref concept_asynchrone "asynchrone" lance un processu d'acquisition en tche de fond.

   \n Cette fonction permet de savoir le nombre d'chantillons que la station a envoy
   et qui peuvent tre lues avec les fonctions de lectures asynchrones : #Ainscan_buff, #Ainfscan_buff, etc...
   \n
   \n Le paramtre \a stop, permet en mme temps de savoir si le processus d'acquisition asynchrone n'a pas t stopp 
   (auquel cas la fonction #Get_last_error pourra en donner la cause).

	\return \ret_error_Def
*/  
//---------------------------------------------------------------------------------------
//! FIXDOC
C_DECL_START
//-----------
DEXPORT(short)
Test_buff(
			  ULONG		*ech_disponible	//!< OUT: nombre de valeur 16 bits disponible pour lecture
			, WORD		*stop			/**!< OUT: etat de la procdure d'acquisition : 
													-# 0 => en cours
													-# 1 => stoppe
										*/
			, ULONG     exts			//!< \arg_unused                 
			, WORD      carte 			//!< \arg_carteType_Def     
			, WORD		adresse			//!< \arg_carteNum_Def
    );


//------------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Test_buff)(
						  ULONG		*ech_disponible	
						, WORD		*stop			
						, ULONG     exts			
						, WORD      carte 			
						, WORD		adresse			
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Test_buff		pf_Test_buff;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//------------------



//---------------------------------------------------------------------------------------
//! \brief Stop un processus d'chantillonage asynchrone
/**
	Un appel  l'une des fonctions ??scan (ex. #Ainfscan(), #Ainscan(), ... )
	, en activant le mode \ref concept_asynchrone "asynchrone" lance un processu d'acquisition en tche de fond.
	\n Cette fonction permet de l'arrter.

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
StopScan( 
				ULONG exts		//!< \arg_unused_ext
			  , USHORT carte	//!< \arg_carteType_Def
			  , USHORT adresse	//!< \arg_carteNum_Def
		  );

//--------------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_StopScan)(
						ULONG exts
					  , USHORT carte
					  , USHORT adresse
				);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_StopScan		pf_StopScan;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//--------------------



//##########################################################################
/*! @}*/ // Fin de ACQUISITION_group
//##########################################################################




















//##########################################################################
/**
	\addtogroup RESTITUTION_group Fonctions de restitution
	\ingroup API_group

	\par
	Sont regroups ici les fonctions permettant de manipuler les sorties de la station.
	\par
	Les restitutions se font sur les voies en sortie de la station. Ces voies pouvant tre de type :
		- Analogique : ces voies permettent de choisir la tension de sortie dans l'intervalle permis par la station (cf. doc technique de celle-i).
		- Digitale   : ces voies regroupe plusieurs lignes binaires dont l'tat ne peut tre que soit 0 ou 1.
	\par
	Pour connaitre le nombre et les caractristiques des voies analogiques et digitales gres par la station
	, veuillez vous rfrer  sa doc technique.
	\par
	Ce document liste toutes les fonctions de restitution disponibles, mme les plus sothriques.
	\par
	Mais les fonctions les plus courament utilises sont:
			\if USE_BIN_FCTS
		- #BOut()  : fixe l'tat d'une ligne binaire (ie. appartenant  une voie digitale)
			\endif
		- #Dout()  : fixe l'tat d'un groupe de ligne binaires (ie. d'une voie digitale)
		- #Aoutf() : fixe la tension de sortie d'une ligne analogique
	\par
	Et leurs fonctions complmentaires permettant de faire des restitutions en rafale : #Doutscan, #Aoutfscan(), ...
	\par
	Les restitutions ne sont disponibles qu'en mode synchrone : les appels ne retournent que 
	lorsque l'opration est termine.

	\n
	\n

	@{
*/
//##########################################################################

//---------------------------------------------------------------------------------------
//! \brief Fixe la valeur d'un des port digitaux de la carte
/*
    Un port digital contient en gnral 8 lignes binaires
    La valeur retourne dans \a data dcrira l'tat de chacune de ces lignes binaires
    en suivant la rgle: 
		-# data[0] == tat de la ligne 0
		-# data[1] == tat de la ligne 1
		-# etc...

		\if USE_DINIT
	\warning Certaines carte ncessitent que la voie digitale ait t prcdement configure 
		en sortie avec #DInit()
		\endif
	
		\if COLL_OUVERT
	\warning Les voies digitales de cette station sont en collecteur ouvert ET en logique ngative
		\n ie. criture d'une ligne du port  1 => la voie sera  0 en sortie
		\endif

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Dout(		
			  USHORT data			//!< valeur  fixer pour le port
			, USHORT port_composant	//!< \arg_Num_Voie_Digit_Carte_Solo_Def
			, USHORT no_composant	//!< \arg_composantDigital_Def
			, USHORT carte			//!< \arg_carteType_Def
			, USHORT adresse		//!< \arg_carteNum_Def
		);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Dout)(
			  USHORT data
			, USHORT port_composant
			, USHORT no_composant
			, USHORT carte
			, USHORT adresse
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Dout		pf_Dout;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! \brief Programmer la station pour des restitutions digitales rgulires
/**
	   Permet de gnrer des signaux sur des voies en sortie digitale.
	\n Les restitutions sont faites  \a frquence donne, les valeurs des restitutions sont extraites
	du \ref concept_tampon "tampon" utilisateurs, et sur un groupe de voies en sortie digitale.
	\n Cette fonction est \ref concept_asynchrone "synchrone" (ie. elle ne retourne pas avant que toutes les restitutions aient t faites)
FIXDOC
		\if USE_DINIT
	\warning Les voies digitales doit avoir t configures en mode sortie par un appel prcdent  #Dinit()
		\endif

		\if COLL_OUVERT
	\warning Les voies digitales de cette station sont en collecteur ouvert ET en logique ngative
		\n ie. criture d'une ligne du port  1 => la voie sera  0 en sortie
		\endif

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Doutscan(	
			  USHORT voie_tampon	//!< \arg_VoieTampon_OUT_Def
			, USHORT port_composant	//!< \arg_VoieCarte_OUT_Def
			, USHORT n_voies_tampon	//!< \arg_TamponNbVoie_Def
			, USHORT n_ports		//!< \arg_NbVoieCarte_OUT_Def
			, USHORT no_composant	//!< \arg_composantDigital_Def
			, ULONG  n_val          //!< \arg_nb_Samples_IN 
			, ULONG  *frequence     //!< \arg_freq_OUT
			, USHORT mode			//!< mode de configuration generateur interne
			, UCHAR  *tampon		//!< \arg_Tampon_OUT_Def
			, ULONG  ext			//!< \arg_unused_ext 
			, USHORT carte			//!< \arg_carteType_Def
			, USHORT adresse		//!< \arg_carteNum_Def
			);


//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Doutscan)(
				  USHORT voie_tampon  
				, USHORT port_composant         
				, USHORT n_voies_tampon  
				, USHORT n_ports      
				, USHORT no_composant 
				, ULONG  n_val         
				, ULONG  *frequence    
				, USHORT mode         
				, UCHAR  *tampon 
				, ULONG  ext           
				, USHORT carte        
				, USHORT adresse       
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Doutscan		pf_Doutscan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//-----------------
//! \cond USE_BIN_FCTS
//---------------------------------------------------------------------------------------
//! \brief Fixe l'tat d'une ligne binaire d'une voie en sortie digitale
/**
\if COLL_OUVERT
	Les ports de la gamme UsbLab sont en collecteur ouvert ET en logique ngative
			\n ie. si "bData" == 1 => la voie sera  0 en sortie
\else
	Si bData == 0 alors l'tat de la ligne binaire sera fixe  l'tat bas, sinon  l'tat haut.
\endif

	\return \ret_error_Def
*/
C_DECL_START
//-----------
DEXPORT(SHORT)
BOut(		
			  USHORT bData			//!< Valeur  crire pour cette ligne du port (0 ou 1)
			, USHORT num_ligne		//!< \arg_num_ligne
			, USHORT port_composant //!< \arg_Num_Voie_Digit_Carte_Solo_Def
			, USHORT no_composant	//!< \arg_composantDigital_Def
			, USHORT carte			//!< \arg_carteType_Def
			, USHORT adresse		//!< \arg_carteNum_Def
		);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_BOut)(
				  USHORT bData        
				, USHORT num_ligne    
				, USHORT port_composant        
				, USHORT no_composant 
				, USHORT carte        
				, USHORT adresse      
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_BOut		pf_BOut;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END
//-----------
/*! \endcond */ // USE_BIN_FCTS
//-----------



//---------------------------------------------------------------------------------------
//! \brief Fixer la tension de sortie d'une des voies en sortie Analogique
/**
	\warning Cette fonction est l uniquement pour compatibilit, prfrez l'utilisation de #Aoutf()
	\warning le paramtre \a data ne reprsente pas la tension de sortie, mais une valeur
		brute qui sera passe interprte par la station.

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Aout(
		   USHORT data       //!< Valeur brute  fixer (pour fixer une tension, voir #Aoutf())
		 , USHORT voie       //!< \arg_Num_Voie_Anal_Carte_Solo_Def
		 , USHORT mode       //!< \arg_mode_OUT
		 , ULONG  exts       //!< \arg_unused_ext
		 , USHORT carte      //!< \arg_carteType_Def
		 , USHORT adresse    //!< \arg_carteNum_Def
	 );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Aout)(
				   USHORT data       
				 , USHORT voie       
				 , USHORT mode       
				 , ULONG  exts        
				 , USHORT carte      
				 , USHORT adresse    
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Aout		pf_Aout;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! \brief Restitue une tension sur une voie en sortie analogique
/**
	\n
	\n La tension ainsi fixe, est maintenue par la station jusqu' un appel ultrieur  #Aoutf() ou \ref RESTITUTION_group "affilie".

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Aoutf(
		   float  data       //!< Tension  fixer
		 , USHORT voie       //!< \arg_Num_Voie_Anal_Carte_Solo_Def
		 , USHORT mode       //!< \arg_mode_OUT
		 , ULONG  exts       //!< \arg_unused_ext
		 , USHORT carte      //!< \arg_carteType_Def
		 , USHORT adresse    //!< \arg_carteNum_Def
	 );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Aoutf)(
				   float data       
				 , USHORT voie      
				 , USHORT mode      
				 , ULONG exts       
				 , USHORT carte     
				 , USHORT adresse	
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Aoutf		pf_Aoutf;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! \brief Gnration de signaux analogique
/**
	\warning Cette fonction est similaire  #Ainfscan(), sauf qu'elle n'effectue pas les conversions en tension.
	\n Aussi il est conseill d'utiliser de prfrerence #Ainfscan().
	
	\n Veuillez vous reportez  la documentation de #Aoutfscan() pour des explications dtaills sur les paramtres.

*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Aoutscan(					
			  USHORT voie_tampon	//!<  \arg_VoieTampon_OUT_Def
			, USHORT voie_da        //!<  \arg_VoieCarte_OUT_Def
			, USHORT n_voies_max	//!<  \arg_TamponNbVoie_Def
			, USHORT n_voies_da     //!<  \arg_NbVoieCarte_OUT_Def
			, ULONG  n_val	  		//!<  \arg_nb_Samples_OUT 
			, ULONG  *frequence	  	//!<  \arg_freq_OUT
			, USHORT tint       	//!<  toujours a 0
			, USHORT mode			//!<  \arg_mode_OUT
			, USHORT polarite[] 	//!<  \arg_polarite_OUT
			, USHORT *tampon		//!<  \arg_Tampon_OUT_Def
			, ULONG  ext            //!<  \arg_unused_ext 
			, USHORT carte 	 		//!<  \arg_carteType_Def
			, USHORT adresse		//!<  \arg_carteNum_Def
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Aoutscan)(
					  USHORT voie_tampon	
					, USHORT voie_da        
					, USHORT n_voies_max	
					, USHORT n_voies_da     
					, ULONG n_val	  		
					, ULONG *frequence	  	
					, USHORT tint       	
					, USHORT mode			
					, USHORT polarite[] 	
					, USHORT *tampon		
					, ULONG ext             
					, USHORT carte 	 		
					, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Aoutscan		pf_Aoutscan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! \brief Gnration de signaux analogique
/**
	   Permet de gnrer des signaux sur des voies en sortie analogique, en programmant la station
	   pour des restitutions  une \a frquence donne.
	\n Les valeurs des restitutions sont extraites du \ref concept_tampon "tampon" utilisateur,
		et les restitutions sont faites sur un groupe de voies en sortie analogique.
	\n Cette fonction est \ref concept_asynchrone "synchrone" (ie. elle ne retourne pas avant que toutes les restitutions aient t faites)

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
DEXPORT(SHORT)
Aoutfscan(				
			  USHORT voie_tampon	//!<  \arg_VoieTampon_OUT_Def
			, USHORT voie_da        //!<  \arg_VoieCarte_OUT_Def
			, USHORT n_voies_max	//!<  \arg_TamponNbVoie_Def
			, USHORT n_voies_da     //!<  \arg_NbVoieCarte_OUT_Def
			, ULONG  n_val	  		//!<  \arg_nb_Samples_OUT
			, ULONG  *frequence	  	//!<  \arg_freq_OUT
			, USHORT tint       	//!<  \arg_unused_zero
			, USHORT mode			/*!<  \arg_mode_OUT
										\if SCAN_REQUIERT_DT_AD_TIM
											\n REQUIS : (mode & #DT_AD_TIM) == 1
										\endif
									*/
			, USHORT polarite[] 	//!<  \arg_polarite_OUT
			, float  *tampon		//!<  \arg_Tampon_OUT_Def
			, ULONG  ext			//!<  \arg_unused_ext 
			, USHORT carte 	 		//!<  \arg_carteType_Def
			, USHORT adresse		//!<  \arg_carteNum_Def
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Aoutfscan)(
					  USHORT voie_tampon	
					, USHORT voie_da        
					, USHORT n_voies_max	
					, USHORT n_voies_da     
					, ULONG n_val	  		
					, ULONG *frequence	  	
					, USHORT tint       	
					, USHORT mode			
					, USHORT polarite[] 	
					, float *tampon			
					, ULONG ext				
					, USHORT carte 	 		
					, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Aoutfscan		pf_Aoutfscan;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//##########################################################################
/*! @}*/ // Fin de RESTITUTION_group
//##########################################################################















////////////////////////////////////////////////
//		Gnrateur et compteur 
////////////////////////////////
//-----------
//! \cond USE_GROUP_GENERATOR_COMPTEUR
//##########################################################################
/**
	\addtogroup GENERATOR_COMPTEUR_group Fonctions relatives aux Gnrateurs de signals et aux compteurs
	\ingroup API_group
	@{
*/
//##########################################################################


//-----------
//! \cond USE_GENERATORS

//---------------------------------------------------------------------------------------
//! \brief Initialise le gnrateur
/** 
	FIXME : qu'est ce qu'un gnrateur

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Ginit(		
		  ULONG  *frequence		//!<  frquence du gnrateur
		, USHORT no_composant	//!<  voir numero du composant Define DT_TIM_XXXX (selon carte)
		, USHORT mode			//!<  voir mode Define DT_TIM_GXXX (selon carte)
		, USHORT carte          //!< \arg_carteType_Def
		, USHORT adresse		//!<  \arg_carteNum_Def
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Ginit)(
				  ULONG  *frequence		
				, USHORT no_composant	
				, USHORT mode			
				, USHORT carte          
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Ginit		pf_Ginit;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! \brief Valide la Gate (programmable) du compteur  pour dmarrer le gnrateur
/** 
	FIXME : qu'est ce qu'un gnrateur

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Gstart(
			  USHORT no_composant	//!<  voir numero du composant Define DT_TIM_XXXX (selon carte)
			, USHORT mode			//!<  voir mode Define DT_TIM_GXXX (selon carte)
			, USHORT carte			//!< \arg_carteType_Def
			, USHORT adresse		//!<  \arg_carteNum_Def
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Gstart)(
				  USHORT no_composant	
				, USHORT mode			
				, USHORT carte			
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Gstart		pf_Gstart;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! \brief Stoppe le gnrateur par la Gate ou par criture
/**
	FIXME : qu'est ce qu'un gnrateur ? Qu'est ce que la Gate ?

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Gstop(	
		  USHORT no_composant	//!<  voir numero du composant Define DT_TIM_XXXX (selon carte)
		, USHORT mode           //!<  voir mode Define DT_TIM_GXXX (selon carte)
		, USHORT carte          //!< \arg_carteType_Def
		, USHORT adresse		//!<  \arg_carteNum_Def
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Gstop)(
				  USHORT no_composant	
				, USHORT mode           
				, USHORT carte          
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Gstop		pf_Gstop;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END

/*! \endcond */ // USE_GENERATORS
//-----------




//-----------
//! \cond USE_COMPTEURS

//---------------------------------------------------------------------------------------
//! \brief Initialise le compteur 
/**
	(FIXME : le compteur du gnrateur ?)

	\return \ret_error_Def
*/
C_DECL_START
//-----------
DEXPORT(SHORT)
Cinit(			
		  USHORT valeur			//!<  valeur de dpart du compteur
		, USHORT no_composant	//!<  voir numero du composant Define DT_TIM_XXXX (selon carte)
		, USHORT mode			//!<  voir mode Define DT_TIM_GXXX (selon carte)
		, USHORT carte			//!< \arg_carteType_Def
		, USHORT adresse		//!<  \arg_carteNum_Def
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Cinit)(
				  USHORT valeur			
				, USHORT no_composant	
				, USHORT mode			
				, USHORT carte			
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Cinit		pf_Cinit;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//! \brief Valide la Gate du compteur pour dmarrer le comptage (FIXME : le compteur du gnrateur ?)
/**
	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Cstart(			
			  USHORT no_composant	//!< voir numero du composant Define DT_TIM_XXXX (selon carte)
			, USHORT carte			//!< \arg_carteType_Def
			, USHORT adresse		//!< \arg_carteNum_Def
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Cstart)(
				  USHORT no_composant	
				, USHORT carte			
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Cstart		pf_Cstart;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! \brief Stoppe le compteur par la Gate ou par criture 
/**
	(FIXME : le compteur du gnrateur ? Qu'est ce que la Gate ? )

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Cstop(		
			  USHORT no_composant	//!< voir numero du composant Define DT_TIM_XXXX (selon carte)
			, USHORT carte			//!< \arg_carteType_Def
			, USHORT adresse		//!< \arg_carteNum_Def
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Cstop)(
				  USHORT no_composant	
				, USHORT carte			
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Cstop		pf_Cstop;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! \brief Permet de lire le compteur (FIXME : le compteur du gnrateur ?)
/**
	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Cread(		
			  USHORT *data			//!< valeur lue sur le compteur
			, USHORT no_composant	//!< voir Define DT_TIM_XXXX (selon carte)
			, USHORT carte			//!< \arg_carteType_Def
			, USHORT adresse		//!< \arg_carteNum_Def
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Cread)(
				  USHORT *data			
				, USHORT no_composant	
				, USHORT carte			
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Cread		pf_Cread;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! \brief Permet de lire le compteur (FIXME : le compteur du gnrateur ?)
/**
	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Cread32(		
			  DWORD *data			//!< valeur lue sur le compteur 32 bits unsigned long
			, USHORT no_composant	//!< voir Define DT_TIM_XXXX (selon carte)
			, USHORT carte			//!< \arg_carteType_Def
			, USHORT adresse		//!< \arg_carteNum_Def
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Cread32)(
				  DWORD *data			
				, USHORT no_composant	
				, USHORT carte			
				, USHORT adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Cread32		pf_Cread32;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END

/*! \endcond */ // USE_COMPTEURS
//-----------





//---------------
//! \cond USE_SIGNAL_GENERATORS
//----------------

//---------------------------------------------------------------------------------------
//! \brief FIXDOC
/**
	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Gs_init(
			  WORD voie_da              //!< voie de sortie ananlogique
			, WORD mode                 //!< mode de generation mode=sinus / mono ou bipolaire
			, WORD horloge              //!< horloge utilise par la carte en MHZ 1=2MHz,2=4MHZ,3=10MHz4=25MHz
			, WORD phase                //!< dcalage de phase en degr de 1  360
			, ULONG *frequence			//!< de 1 Hz  1KHz generation logicielle
			, ULONG exts		        //!< extension future 
			, WORD carte				//!< \arg_carteType_Def
			, WORD adresse				//!< \arg_carteNum_Def
		);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Gs_init)(
				  WORD voie_da              
				, WORD mode                 
				, WORD horloge             
				, WORD phase                
				, ULONG *frequence			
				, ULONG exts		        
				, WORD carte				
				, WORD adresse				
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Gs_init		pf_Gs_init;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! \brief FIXDOC
/**
	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Gs_stop(
			  WORD voie_da		//!< numro de la voie da a arreter
			, ULONG exts		//!< extension future 
			, WORD carte		//!< \arg_carteType_Def
			, WORD adresse		//!< \arg_carteNum_Def
	);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Gs_stop)(
					  WORD voie_da		
					, ULONG exts		
					, WORD carte		
					, WORD adresse		
			 );

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Gs_stop		pf_Gs_stop;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//----------------------
/*! \endcond */ // USE_SIGNAL_GENERATORS
//----------------------

//##########################################################################
/*! @}*/ // Fin de GENERATOR_COMPTEUR_group
//##########################################################################

/*! \endcond */ // USE_GROUP_GENERATOR_COMPTEUR
//----------------------











//|||||||||||||||||||||||||||||
// 
// Fonctions pour cartes supportant le contrle d'un potentiometre numrique
//
//! \cond USE_POT
//|||||||||||||||||||||||||||||

//##########################################################################
/**
	\addtogroup Fcts_Pot_group Fonctions relatives au potentiomtre 
	\ingroup API_group

	\par
	Les fonctions qui suivent permettent de contler l'ventuel potentiomtre numrique gr par la station.
	\par
	Ces fonctions permettent :
		- Modification : changer les paramtres de calibrage du potentiomtre
		- Restauration : restaurer des paramtres de calibrage sauvegards en EEPROM
		- Lecture : lire valeurs ou paramtres de calibrages

	\n
	\n

	@{
*/
//##########################################################################



//---------------------------------------------------------------------------------------
//! \brief Ecriture dans le potentiometre numrique
/**
\warn_fct_mal_documente

Si possible utilisez plutt la fonction #Calibrage_An() pour calibrer le potentiomtre numrique

Ecriture comande et valeur dans le potentiometre numerique
de rglage gain et offset du convertisseur A/N

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Write_Pot(
                  USHORT data		//!< valeur a crire
                , USHORT cde		//!< commande et adresse
				, USHORT ext		//!< \arg_unused
				, USHORT carte		//!< \arg_carteType_Def
                , USHORT adresse	//!< \arg_carteNum_Def
          );

//------------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Write_Pot)(
						  USHORT data		
						, USHORT cde		
						, USHORT ext		
						, USHORT carte		
						, USHORT adresse	
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Write_Pot		pf_Write_Pot;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//------------------







//---------------------------------------------------------------------------------------
//! \brief Lecture du potentiomtre numrique
/**
\warn_fct_mal_documente

Requete (valeur et position) ou mmoire EEPROM du potentiometre numerique 
du rglage gain et offset du convertisseur A/N pour lecture =>
	-# USB_Write_pot Cde 9 ou 10
	-# puis USB_Read_Pot Cde0 NOP pour lecture sur SDO

\note Cde 9: lecture memoire EEMEN(ADDR) et 10: lecture valeur 8 bits RDAC(A0)
  \n	ADDR=2=USR1  15=USR14                   A0=0=RDAC1 et 1=RDAC2

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Read_Pot(
              USHORT *result		//!< OUT: valeur lue
            , USHORT cde			//!< commande et adresse (non utilis = NOP par defaut)
			, USHORT ext			//!< \arg_unused
			, USHORT carte			//!< \arg_carteType_Def
            , USHORT adresse		//!< \arg_carteNum_Def
          );

//---------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Read_Pot)(
						  USHORT *result		
						, USHORT cde			
						, USHORT ext			
						, USHORT carte			
						, USHORT adresse		
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Read_Pot		pf_Read_Pot;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//---------------








//---------------------------------------------------------------------------------------
//! \brief Calibrage du potentiomtre
/** 
	\n Cette fonction effectue le calibrage du convertisseur Analogique/Numrique 
	du potentiomtre en rglant son gain et offset

	\return \ret_error_Def
*/
C_DECL_START
//-----------
DEXPORT(short)
Calibrage_An(
                  USHORT cde        //!< operation a effectuer, valeurs parmi #CALIBRAGE_MODE
                , USHORT action		//!< fonctions  raliser, valeur parmi #CALIBRAGE_ACTION
				, USHORT voie_ref	//!< voie connecte  la tension de calibrage: rglage pleine chelle GAIN
                , USHORT voie_gnd	//!< voie connecte au 0 volt de rfrence AGND : rglage du 0 OFFSET
                , float  ref_volts	//!< tension de rfrence pour le calibrage
				, USHORT carte		//!< \arg_carteType_Def
                , USHORT adresse	//!< \arg_carteNum_Def
			);

//---------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Calibrage_An)(
						  USHORT cde        
						, USHORT action		
						, USHORT voie_ref	
						, USHORT voie_gnd	
						, float  ref_volts	
						, USHORT carte		
						, USHORT adresse	
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Calibrage_An		pf_Calibrage_An;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//---------------



//##########################################################################
/*! @}*/ // Fin de Fcts_Pot_group
//##########################################################################

//|||||||||||||||||||||||||||||
/*! \endcond */ // USE_POT
//|||||||||||||||||||||||||||||















//-----------------------------------
//! \cond USE_GROUP_FCTS_CONVERSION
//##########################################################################
/**
	\addtogroup FCTS_CONVERSION_group Fonctions relatives aux paramtres de conversion
	\ingroup API_group
	@{
*/
//##########################################################################


//-------------------------------
//! \cond USE_PLEINE_ECHELLE_AD

//---------------------------------------------------------------------------------------
//! \brief Permet l'acces aux paramtres de conversion d'une voie en entre analogique
/**
	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
GetPleineEchelleAD( 
						  FLOAT* pleineEchelleAD	//!< OUT: Pleine-Echelle AD
						, USHORT* polarite			//!< OUT: mode : bipolaire (1) ou monopolaire (0
						, USHORT voie				//!< numro de voie concern
						, ULONG exts				//!< \arg_unused
						, USHORT carte				//!< \arg_carteType_Def
						, USHORT adresse			//!< \arg_carteNum_Def
					);


//--------------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_GetPleineEchelleAD)(
							  FLOAT* pleineEchelleAD
							, USHORT* mode
							, USHORT voie
							, ULONG exts
							, USHORT carte
							, USHORT adresse 
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_GetPleineEchelleAD		pf_GetPleineEchelleAD;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//--------------------






//---------------------------------------------------------------------------------------
//! \brief Change les paramtres de la fonction de conversion d'une voie en entre analogique
/**
	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
SetPleineEchelleAD( 
						  FLOAT pleineEchelleAD			//!< Nouveau max/min pour les tensions lues
				   		, short polarite				//!< Dfinit le mode de polarit pour la voie (cf. #E_TYPE_POLARITE)
						, USHORT voie					//!< Numro de la voie d'entre analogique  configurer \n NOTE : V0 => 0, V1 => 1, etc...
						, ULONG exts					//!< \arg_unused
						, USHORT carte					//!< \arg_carteType_Def
						, USHORT adresse				//!< \arg_carteNum_Def
					);



//--------------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_SetPleineEchelleAD)(
							  FLOAT pleineEchelleAD
							, short polarite
							, USHORT voie
							, ULONG exts
							, USHORT carte
							, USHORT adresse 
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_SetPleineEchelleAD		pf_SetPleineEchelleAD;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//--------------------

//--------------------
/*! \endcond */ // USE_PLEINE_ECHELLE_AD
//---------------------------









//--------------------
//! \cond USE_PLEINE_ECHELLE_DA
//---------------------------

//---------------------------------------------------------------------------------------
//! \brief Permet l'acces aux paramtres de conversion d'une voie en sortie analogique
/**
	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
GetPleineEchelleDA( 
						  FLOAT* pleineEchelleDA	//!< OUT: Pleine-Echelle DA
						, USHORT* polarite			//!< OUT : mode de polarit de la voie (cf. #E_TYPE_POLARITE)
						, USHORT voie				//!< numro de voie concern
						, ULONG exts				//!< \arg_unused
						, USHORT carte				//!< \arg_carteType_Def
						, USHORT adresse			//!< \arg_carteNum_Def
					);

//--------------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_GetPleineEchelleDA)(
							  FLOAT* pleineEchelleDA
							, USHORT* polarite
							, USHORT voie
							, ULONG exts
							, USHORT carte
							, USHORT adresse 
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_GetPleineEchelleDA		pf_GetPleineEchelleDA;	
/*! \endcond */ // NEVER
//-----------


C_DECL_END
//--------------------








//---------------------------------------------------------------------------------------
//! \brief Change les paramtres de la fonction de conversion d'une voie en sortie analogique
/**
	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
SetPleineEchelleDA( 
						  FLOAT pleineEchelleDA	//!< Pleine-Echelle DA
				   		, USHORT mode			//!< Dfinit le mode : bipolaire (1) ou monopolaire (0)
						, USHORT voie			//!< numro de voie  configurer
						, ULONG exts			//!< \arg_unused
						, USHORT carte			//!< \arg_carteType_Def
						, USHORT adresse		//!< \arg_carteNum_Def
					);

//--------------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_SetPleineEchelleDA)(
							  FLOAT pleineEchelleDA
				   			, USHORT mode
							, USHORT voie
							, ULONG exts
							, USHORT carte
							, USHORT adresse
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_SetPleineEchelleDA		pf_SetPleineEchelleDA;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//--------------------
/*! \endcond */ // USE_PLEINE_ECHELLE_DA
//---------------------------



//##########################################################################
/*! @}*/ // Fin du groupe FCTS_CONVERSION_group
//##########################################################################
/*! \endcond */ // USE_GROUP_FCTS_CONVERSION
//---------------------------












//---------------------------
//! \cond USE_GROUP_TRIGGERS
//##########################################################################
/**
	\addtogroup TRIGGERS_group Fonctions relatives  aux dclencheurs d'acquisition ou de restitutions
	\ingroup API_group
	@{
*/
//##########################################################################


//---------------------------
//! \cond USE_TRIGGER_AD

//---------------------------------------------------------------------------------------
//! \brief Mise en place de nouvelle donnes de declenchement par voie d'entre analogique
/*	Cette fonction enregistre 
		-# la voie d'entre analogique  utiliser comme dclencheur
		-# la tension de declenchement

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
SetTriggerAD( 
					USHORT voieAD		//!< Numro de la voie d'entre analogique  utiliser \n NOTE : V0 => 0, V1 => 1, etc...
				  , FLOAT  triggerAD	//!< Seuil de declenchement en Volt
				  , ULONG exts			//!< \arg_unused
				  , USHORT carte		//!< \arg_carteType_Def
				  , USHORT adresse		//!< \arg_carteNum_Def
			  );

//--------------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_SetTriggerAD)(
							USHORT voieAD	
						  , FLOAT  triggerAD	
						  , ULONG exts
						  , USHORT carte
						  , USHORT adresse
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_SetTriggerAD		pf_SetTriggerAD;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//--------------------







//---------------------------------------------------------------------------------------
//! \brief Permet l'acces aux donnes relatives  un dclencheur sur entre analogique
/** Renvoie dans ses paramtres OUT :
		-# la voie d'entre analogique utilise par le dclencheur
		-# la tension seuil de dclenchement

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
GetTriggerAD( 
				    USHORT* pvoieAD     //!< OUT : Numro de la voie d'entre analogique utilise \n NOTE : V0 => 0, V1 => 1, etc...
				  , FLOAT* ptriggerAD   //!< OUT: seuil de declenchement en Volt
				  , ULONG exts			//!< \arg_unused
				  , USHORT carte		//!< \arg_carteType_Def
				  , USHORT adresse		//!< \arg_carteNum_Def
			  );

//--------------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_GetTriggerAD)(
							USHORT* pvoieAD     
						  , FLOAT* ptriggerAD   
						  , ULONG exts
						  , USHORT carte
						  , USHORT adresse 
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_GetTriggerAD		pf_GetTriggerAD;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//--------------------


/*! \endcond */ // USE_TRIGGER_AD
//---------------------------



//##########################################################################
/*! @}*/ // Fin du groupe TRIGGERS_group
//##########################################################################
/*! \endcond */ // USE_GROUP_TRIGGERS
//---------------------------











//-------------------------
//! \cond USE_CAPTEUR
//##########################################################################
/**
	\addtogroup CAPTEUR_group Fonctions relatives aux ventuels capteurs associe  la station
	\ingroup API_group
	@{
*/
//##########################################################################

//-------------------------------------------
//! \brief Configurer ou demander la configuration d'un capteur
/**
\param xpcapt : 
	-# si c'est une demande de l'tat d'une carte => la rponse sera stocke l.
	-# si c'est une requete de configuration => contient la configuration voulue pour ce capteur
\param flag : 
	-# si flag == FALSE => l'appelant veut connaitre la configuration du capteur
	-# si flag == TRUE  => l'appelant veut (re)configurer le capteur /warning Non impment

	\return \ret_error_Def
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(void)
Init_Capt(
			  CAPT *xpcapt
			, short flag
			);   


// Dclaration de prototye de la fonction ci-dessus
//! \cond NEVER
PROTO_DECL(void)
(PASCAL *PROTO_Init_Capt)(
					  CAPT *xpcapt
					, short flag		//Init_Capt
					);   

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Init_Capt	pf_Init_Capt;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END





//---------------
//! \cond USE_CAPT_EEPROM


//---------------------------------------------------------------------------------------
//! \brief Ecriture dans la mmoire eeprom i2c capteur
/**
   Utilisation de la memoire i2c de 2K bits = 256 octets disponible sur chaque capteur.
   info: adresse du capteur0 = 0  FF capteur0 = 100  1FF et capteur0 = 200 2FF
   Ecriture par mots de 16 bits => adresse de 0  63 => adrmem x2

	\return \ret_error_Def
*/
C_DECL_START
//-----------
DEXPORT(short)
Capt_WriteEep(
				    USHORT data			//!<  valeur du mot de 16 bits a ecrire
				  , USHORT adrmem		//!<  adresse memoire de 0  127
				  , USHORT nr_capteur	//!<  numro du capteur de 0  7
				  , USHORT ext			//!<  \arg_unused
				  , USHORT carte		//!<  \arg_carteType_Def
				  , USHORT adresse		//!<  \arg_carteNum_Def
			  );

//---------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Capt_WriteEep)(
							USHORT data			
						  , USHORT adrmem		
						  , USHORT nr_capteur	
						  , USHORT ext			
						  , USHORT carte		
						  , USHORT adresse		
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Capt_WriteEep		pf_Capt_WriteEep;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//---------------





//---------------------------------------------------------------------------------------
//! \brief Lecture dans la mmoire eeprom i2c capteur
/**
   Utilisation de la memoire i2c de 2K bits = 256 octets disponible sur chaque capteur.
   info: adresse du capteur0 = 0  FF capteur0 = 100  1FF et capteur0 = 200 2FF
   Lecture par mots de 16 bits => adresse de 0  63 => adrmem x2

	\return \ret_error_Def
*/
C_DECL_START
//-----------
DEXPORT(short)
Capt_ReadEep(
				   USHORT *data			//!< OUT: valeur de mots de 16 bits lu
				 , USHORT adrmem		//!< adresse memoire de 0  127
				 , USHORT nr_capteur	//!< numro du capteur de 0  7
				 , USHORT ext			//!< \arg_unused
				 , USHORT carte			//!< \arg_carteType_Def
				 , USHORT adresse		//!< \arg_carteNum_Def
			 );

//---------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Capt_ReadEep)(
						   USHORT *data			
						 , USHORT adrmem		
						 , USHORT nr_capteur	
						 , USHORT ext			
						 , USHORT carte			
						 , USHORT adresse		
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Capt_ReadEep		pf_Capt_ReadEep;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//---------------

/*! \endcond */ // USE_CAPT_EEPROM
//---------------


/*! \endcond */ //USE_CAPTEUR
//-------------------------

//##########################################################################
/*! @}*/ // Fin de CAPTEUR_group
//##########################################################################












//------------------------
//! \cond USE_EVENTS

//##########################################################################
/**
	\addtogroup Event_group Evenements gnrs par la Dll
	\ingroup API_group
	   Structures et fonctions en rapport avec les venements gnrs par la Dll
	@{
*/
//##########################################################################
#pragma pack (2)  //alignement des 2 structures sur 2 octets copatible Digiview

//---------------------------------------------------------------------------------------
//! \brief Utilise par #S_ECHANTILLON pour distinguer le type d'chantillon  contenu
enum enum_digiSample_type
{
	SAMPLE_DIGITAL,		//!< l'chantillon contient un nombre entier
	SAMPLE_ANALOGIQUE,	//!< l'chantillon contient un nombre rel
};

//---------------------------------------------------------------------------------------
//! \brief Donnes d'un chantillon
typedef struct S_ECHANTILLON
{
	USHORT carte_type;							//!< Type de carte ayant gnr l'chantillon
	short  adresse;								//!< Numro de la carte du type #carte_type associe l'chantillon
	BYTE   num_voie;							//!< Numro de la voie qui a chantillonn
	enum   enum_digiSample_type sample_type;	//!< Type de l'chantillon
	DDWORD date;								//!< Date de rception de l'chantillon (en nb ms depuis le dmarrage du systme)

	//! Utilise par #S_ECHANTILLON, valeur de l'chantillon
	union UNION_VAL_SAMPLE
	{
		BYTE  digital;	//!< Valide si #sample_type == SAMPLE_DIGITAL
		float analog;	//!< Valide si #sample_type == SAMPLE_ANALOGIQUE
	};
	//! Valeur de l'chantillon recu
	union UNION_VAL_SAMPLE val;
}
t_digiSample;

//---------------------------------------------------------------------------------------
//! \brief Union des valeurs possible relative  un venement
/**
	Les fonctions callbacks d'
	\htmlonly <a href="group___event__group.html">venement</a> \endhtmlonly 
	utilisent ventuellement cette union pour donner des informations relatives  l'venement.
	\n L'lment de l'union qui est utilise dpend du type d'vement. Par exemple, une venement 
	signalant l'arrive d'un venement utilisera #sample.
	\n Le fichier 'DigiDefs_Events.def.h' dcrit les venements et le type de l'extend CB qu'ils utilisent
*/
union union_cb_ext
{
	BYTE b;
	int i;
	float f;
	t_digiSample* sample;	//! Utilise par les venements relatifs  un chantillons.
};

#pragma pack ()


//---------------------------------------------------------------------------------------
//! Signature des fonctions retour utiliss par les venements (cf. #EventCallBack__Set, #EventCallBack__Get)
//-------------------------------------------------------------------
typedef DIGI_CALLBACK_T(void) (DIGI_CALLBACK_U *t_EvtCB)( int evtID, USHORT carte, USHORT adresse, void* cb_Arg, union union_cb_ext* ext );



//! \cond NEVER
//-------------------------------------------------------------------
// Enumration des evenement susceptibles d'tre utiliss par la Dll
//-------------------------------------------------------------------
enum ENUM_EVENT_TYPES
{
	#define X_DIGI_EVT( ID_EVT, NUM_EVT, STR_DESCRIPTIVE )	\
			ID_EVT = NUM_EVT,

	#include "DigiDefs_Events.def.h"
};
/*! \endcond */ // NEVER


//---------------------------------------------------------------------------------------
//! \brief  Assignation d'une fonction Retour  un vnement
/**
	\warning les fonctions rappels assignes aux \ref concept_events "venements" <em>ne doivent pas</em> 
				appeler des fonctions de l'API.
			\n
			\n Il n'y a qu'une fonction de rappel appele par venement.
			\n Aussi un appel  \a EventCallBack__Set peut remplacer une fonction de rappel -et ses paramtres- mis en place prcdement.
			\n Une exception notable est lorsque evt_ID == USHORT_MAX : la fonction retour mis en place sera alors 
			la fonction retour par dfaut qui sera appel lorsqu'aucune autre fonction retour plus spcifique  l'venement
			n'est disponible.

	\param carte_type  : \arg_carteType_Def
	\param adresse     : \arg_carteNum_Def
	\param evtID       : l'ID de l'venement dclenchant parmi ENUM_EVENT_TYPES  (cf. "DigiDefs_Events.def.h")
						 \n si == USHORT_MAX => \a f_CB deviendra la fonction de retour par dfaut
	\param f_CB        : la fonction retour qui sera appele quand l'venement dclencheur surviendra ou NULL pour annuler l'ventuelle fonction retour dj en place (voir \ref #t_EvtCB)
	\param cb_Arg      : quand \a f_CB sera appele lors d'un vnement
						, son paramtre ponyme aura cette valeur (Optionnel peut-etre NULL)
						\n Si ce paramtre est un pointeur vers une zone malloc, la libration de la mmoire associe est
						 la charge de l'utilisateur

	\return \ret_error_Def
*/
C_DECL_START
//-----------
DEXPORT(SHORT)
EventCallBack__Set(	  
					  USHORT carte_type
					, short adresse
					, USHORT evtID
					, t_EvtCB f_CB
					, void* cb_Arg
					);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_EventCallBack__Set)(
							  USHORT carte_type
							, short adresse
							, USHORT evtID
							, t_EvtCB f_CB
							, void* cb_Arg
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_EventCallBack__Set		pf_EventCallBack__Set;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! \brief Rcupration une fonction de retour d'un \ref concept_events "venement" et ses paramtres
/**
	\param carte_type  : \arg_carteType_Def
	\param adresse     : \arg_carteNum_Def
	\param evtID       : l'ID de l'venement dclenchant parmi ENUM_EVENT_TYPES  (cf. "DigiDefs_Events.def.h")
						 \n si == USHORT_MAX => rcupre la fonction de retour par dfaut
	\param f_CB        : Paramtre rsultat. Au retour *f_CB vaudra la fonction retour recherche ou NULL si aucune
	\param cb_Arg      : Paramtre rsultat. Au retour *cb_Arg vaudra le paramtre associ  f_CB si elle existe ou NULL sinon

	\return \ret_error_Def
*/
C_DECL_START
//-----------
DEXPORT(SHORT)
EventCallBack__Get(	 
				      USHORT carte_type
					, USHORT adresse
					, USHORT evtID
					, t_EvtCB* f_CB
					, void** cb_Arg
					);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_EventCallBack__Get)(
							  USHORT carte_type
							, USHORT adresse
							, USHORT evtID
							, t_EvtCB* f_CB
							, void** cb_Arg
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_EventCallBack__Get		pf_EventCallBack__Get;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END



//##########################################################################
/*! @}*/ // Fin de Event_Group
//##########################################################################

/*! \endcond */ // USE_EVENTS
//------------------------












//! \cond USE_EEPROM
//##########################################################################
/**
	\addtogroup EEPROM_group Fonctions permettant l'acces aux donnes EEProm de la station
	\ingroup API_group
	@{
*/
//##########################################################################


//---------------------------------------------------------------------------------------
//! \brief Lecture du numro id (identifier) de la station switch interne  8 positions
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Get_id(
			  USHORT *deviceID			//!< OUT: identifiant
			, USHORT ext				//!< \arg_unused
			, USHORT carte				//!< \arg_carteType_Def
			, USHORT adresse			//!< \arg_carteNum_Def
		);

//---------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Get_id)(
					  USHORT *deviceID		
					, USHORT ext				
					, USHORT carte				
					, USHORT adresse			
				);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Get_id		pf_Get_id;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//---------------










//---------------------------------------------------------------------------------------
//! \brief ecriture du numro id (identifier) de la station eeprom interne sur 8 bits
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Set_id(
		      USHORT deviceID	//!< id de la station sur 8 bits valides 0  128
			, USHORT ext		//!< \arg_unused
			, USHORT carte		//!< \arg_carteType_Def
            , USHORT adresse	//!< \arg_carteNum_Def
		);

//---------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Set_id)(
					  USHORT deviceID	
					, USHORT ext		
					, USHORT carte		
					, USHORT adresse	
				);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Set_id		pf_Set_id;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//---------------







//---------------------------------------------------------------------------------------
//! \brief Ecriture eeprom mot de 16 bits  dans la zone utilisateur*/
/**
   Zone fixe alloue de 64 mots de 16 bits ( rserve sur la station de $3100  317F =128 octets)
   Ecriture par mots de 16 bits => adresse de 0  63 => adrmem x2 
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
User_WriteEep(
				    USHORT data		//!< Valeur du mot de 16 bits a ecrire
				  , USHORT adrmem	//!< Adresse memoire de stockage: 0  63
				  , USHORT ext		//!< \arg_unused
				  , USHORT carte	//!< \arg_carteType_Def
				  , USHORT adresse	//!< \arg_carteNum_Def
			  );	

//---------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_User_WriteEep)(
						USHORT data		
					  , USHORT adrmem	
					  , USHORT ext		
					  , USHORT carte	
					  , USHORT adresse	
				);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_User_WriteEep		pf_User_WriteEep;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//---------------






//---------------------------------------------------------------------------------------
//! \brief lecture eeprom mot de 16 bits  dans la zone utilisateur
/**
   Zone fixe alloue de 64 mots de 16 bits ( rserve sur la station de $3100  317F =128 octets)
   Ecriture par mots de 16 bits => adresse de 0  63 => adrmem x2
*/
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
User_ReadEep(
				  USHORT *data		//!< Valeur du mot de 16 bits lue
				, USHORT adrmem		//!< Adresse memoire de lecture: 0  63
				, USHORT ext		//!< \arg_unused
				, USHORT carte		//!< \arg_carteType_Def
				, USHORT adresse	//!< \arg_carteNum_Def
			);	

//---------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_User_ReadEep)(
						  USHORT *data		
						, USHORT adrmem		
						, USHORT ext		
						, USHORT carte		
						, USHORT adresse	
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_User_ReadEep		pf_User_ReadEep;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//---------------





//---------------------------------------------------------------------------------------
//! \brief Lecture du nombre de stations trouvees, lecture du numro id et du nom symbolique
// FIXME : cette fonction retourne ou prend un char* en paramtre, est-ce bien scure ?
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Get_devices(
				  USHORT *nbstations	//!< OUT: nombre de stations detectees
				, char   *devicenom		//!< OUT: pointeur sur Nom symbolique du device
                , USHORT *deviceID		//!< ...
				, USHORT carte			//!< \arg_carteType_Def
                , USHORT adresse		//!< \arg_carteNum_Def
			);

//---------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Get_devices)(
						  USHORT *nbstations	
						, char   *devicenom		
						, USHORT *deviceID		
						, USHORT carte			
						, USHORT adresse		
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Get_devices		pf_Get_devices;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//---------------



//##########################################################################
/*! @}*/ // Fin de EEPROM_group
//##########################################################################

/*! \endcond */ // USE_EEPROM
//------------------------















//##########################################################################
/**
	\addtogroup Misc_group Fonctions atypique de la Dll
	\ingroup API_group
	   Fonctions atypique de la Dll,  usages et effets sothriques et varis
	@{
*/
//##########################################################################



//---------------------------------------------------------------------------------------
//! \brief Lecture du numero de version USB et de la vitesse moyenne de transfert pour un acces Ain()
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
GetInfo_Reseau(	  
					  USHORT *type				//!< OUT:  type de station (Usb==1,...)
					, USHORT *rev				//!< OUT: revision 
					, float  *bandepassante		//!< OUT: bande de passantetaux de transfert pour un transfert Ain()
					, ULONG  *ext				//!< \arg_unused
					, USHORT carte				//!< \arg_carteType_Def
					, USHORT adresse			//!< \arg_carteNum_Def
				);

//---------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_GetInfo_Reseau)(
							  USHORT *type				
							, USHORT *rev				
							, float  *bandepassante	
							, ULONG  *ext				
							, USHORT carte				
							, USHORT adresse			
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_GetInfo_Reseau		pf_GetInfo_Reseau;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//---------------




//---------------------------------------------------------------------------------------
//! \brief Initialisation d'un reseau
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
Init_Reseau(
				  void  * _net_params	//!< Donnes spcifiant la facon dont le rseau doit tre configurer (dpendand du type de rseau)
			);

//---------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Init_Reseau)(
								void  * _net_params
							);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Init_Reseau		pf_Init_Reseau;	
/*! \endcond */ // NEVER
//-----------

C_DECL_END
//---------------






//------------------------
//! \cond USE_VERROUX

//---------------------------------------------------------------------------------------
//! \brief Spcifie la politique de verrouillage  utiliser pour les stations 
/**
	\param b_lock_temporaire : si Vrai les verrouillages dureront le temps de chaque appel  l'API, Sinon les verrouillages dureront le temps du processus.
	\return \ret_error_Def
*/
//-------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Set_Verrouillage_Type( 
						bool b_lock_temporaire
					 );

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Set_Verrouillage_Type)( 
								bool b_lock_temporaire
							);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Set_Verrouillage_Type		pf_Set_Verrouillage_Type;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


/*! \endcond */ // USE_VERROUX
//------------------------



//---------------------------------------------------------------------------------------
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
//! \brief Permet de lire la dernire erreur mmorise par la Dll
/**
	\param erreur : OUT : vaudra la valeur de la dernire erreur rencontre par la Dll
	\param source : type d'erreur  demander  la station (seul 0 est valide pour l'instant)
	\param exts : inutilis
	\param carte : \arg_carteType_Def
	\param adresse : \arg_carteNum_Def
*/
DEXPORT(short)
Get_last_error(
					  short		*erreur		
					, WORD      source
					, ULONG     exts
					, WORD      carte
					, WORD      adresse
			);

//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(short)
(PASCAL *PROTO_Get_last_error)( 
							  short		*erreur 
							, WORD      source		
							, ULONG     exts		
							, WORD      carte 		
							, WORD      adresse		
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Get_last_error		pf_Get_last_error;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END


//! \cond USE_TST_TRIGGER
//---------------------------------------------------------------------------------------
//! \brief Fonction atypique qui permet de tester la ligne PC1 en entre ou d'crire en entre
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(SHORT)
Tst_trigger( 
				  USHORT mode		//!< voir mode de declenchement Define DT_AD_TRGxx (selon carte)
				, USHORT carte		//!< \arg_carteType_Def
				, USHORT adresse	//!< \arg_carteNum_Def
			 );

//---------------
//! \cond NEVER
// Dclaration de prototye de la fonction ci-dessus
PROTO_DECL(SHORT)
(PASCAL *PROTO_Tst_trigger)(
						  USHORT mode		
						, USHORT carte		
						, USHORT adresse	
					);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_Tst_trigger		pf_Tst_trigger;	
/*! \endcond */ // NEVER
//-----------
C_DECL_END
//---------------
/*! \endcond */ // USE_TST_TRIGGER



//##########################################################################
/*! @}*/ // Fin de Misc_Group
//##########################################################################












//##########################################################################
/**
	\addtogroup OUTDLL_group Fonctions hors Dll
	\ingroup API_group
	   Les fonctions prsentes dans cette section ne sont pas prsente dans 
	   la Dll. \n
	   L'utilisateur qui voudra en utiliser une ou plusieurs, devra inclure
	    son projet C/C++ le fichier .c correspondant qui est prsent dans le dossier 
	   "Digi_Commons".
	   \n Chaque fonction signale quel fichier .c l'implmente.

	   \see \ref sect_OutDll_Group, \ref sect_compilation_linking "Compilation"
	@{
*/
//##########################################################################


//-------------------------------------------
//! \brief Retourne la chaine de caractre decrivant l'evenement ayant l'id \a id_event
/**    
	\warning cette fonction est implment dans DigiTool.c qui n'est pas compil avec la Dll.
	\see \ref OUTDLL_group
*/
//-------------------------------------------------------------------
DTYPE_C( const char* )
Digi_GetEventString( int id_event );


//-------------------------------------------
//! \brief Retourne le nom de la carte correspondant
/**    
	\warning cette fonction est implment dans DigiTool.c qui n'est pas compil avec la Dll.
	\see \ref OUTDLL_group
*/
//-------------------------------------------------------------------
DTYPE_C( const char* )
Digi_GetCarte_Nom( 
				  int id_carte //!< \arg_carteType_Def dont on veut un nom "humain"
				);


//-------------------------------------------
//! \brief Retourne le nom de la Dll correspondante
/**    
	\warning cette fonction est implment dans DigiTool.c qui n'est pas compil avec la Dll.
	\see \ref OUTDLL_group, \ref pg_compilation "liaison dynamique"
*/
//-------------------------------------------------------------------
DTYPE_C( const char* )
Digi_GetCarte_Dll( 
					int id_carte	//!< \arg_carteType_Def dont il faut dterminer la Dll associe
				);


//-------------------------------------------
//! \brief (R)Initialise les pointeurs de fonctions dfinis dans DigiTool.h
/**    
	\warning cette fonction est implment dans DigiTool.c qui n'est pas compil avec la Dll.
	\see \ref OUTDLL_group

	\param h_loaded_Dll : Le HMODULE rendu par LoadLibrary()
	\param dll_path : Le chemin de la Dll donne  LoadLibrary()

	\return TRUE si au moins un pointeur de fonction a pu tre initialis
*/
//-------------------------------------------------------------------
DTYPE_C(BOOL)
Digi_Init_Functions_Pointers( HMODULE h_loaded_Dll, P_STR dll_path );



//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//		Erreurs renvoy par les fonctions de la Dll
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

//-------------------------------------------
//! \brief Retourne la chaine de caratre dcrivant l'erreur passe en paramtre
/**    
	\warning cette fonction est implment dans DigiTool.c qui n'est pas compil avec la Dll.
	\see \ref OUTDLL_group
*/
//-------------------------------------------------------------------
DTYPE_C( const char* )
Digi_GetErrorString( int num_err );


//##########################################################################
/*! @}*/ // Fin de OUTDLL_group
//##########################################################################












//##########################################################################
/**
	\addtogroup Enum_Constants_Group     Constantes de l'API
	\ingroup API_group
		
	\par
		Sont listes ici les constantes et numrations utilises par l'API.
	@{
*/
//##########################################################################

//-----------------------------------------
//! \cond NEVER

//-----------------------------------------------
#ifndef USHORT_MAX
	#define USHORT_MAX    _UI16_MAX
#endif
#ifndef SHORT_MAX
	#define SHORT_MAX     _I16_MAX
#endif


//-----------------------------------------------------------------------------------------------------
//! \brief Enumration des association "identifiant d'erreur" => "valeur de l'erreur"
// NOTE : gnre automatiquement par une X-macro utilisant le fichier  "DigiDefs_Errors.def.h"
//-------------------------------------------------------------------
#define D_DIGI_ERR( ID_ERR, NUM_ERR, STR_ERR )	\
	ID_ERR = NUM_ERR,

enum ENUM_DIGI_ERR
{
	#include "DigiDefs_Errors.def.h"
};


//-------------------------------------------
//! \brief Enumration des identifiants de cartes Digimtrie et de leur valeurs
// NOTE : gnre automatiquement par une X-macro utilisant le fichier  "DigiDefs_Cartes.def.h"
//-------------------------------------------------------------------
#define D_CARTE_DIGI( ID, NUM,	 S_NOM, S_DLL )	ID = NUM,

enum ENUM_DIGI_CARTES_IDS
{
	#include "DigiDefs_Cartes.def.h"
};

// Ces cartes ont leur ID qui est un doublon d'un de ceux de #ENUM_DIGI_CARTES_IDS
#define USB_LAB_LP	USB_LAB12
#define USB_LABR	USB2_LAB
#define PCI_OPTO16V PCI_OPTO18V



//////////////////////////////////////////////////////////
//		Dfinition des bits du paramtre mode
///////////////////////////////////////////////
//Pour DINIT
#define DT_DINIT_IN		0x0000 //Entre
#define DT_DINIT_OUT	0x00FF //Sortie



//////////////////////////////////////////////////////////
//		Dfinition des bits a tester du paramtre mode
///////////////////////////////////////////////
//
//mode pour AINxxx et DINxxx
//

// definition des bits utilises pour masquer
#define bmBIT0    0x0001
#define bmBIT1    0x0002
#define bmBIT2    0x0004
#define bmBIT3    0x0008
#define bmBIT4    0x0010
#define bmBIT5    0x0020
#define bmBIT6    0x0040
#define bmBIT7    0x0080
#define bmBIT8    0x0100
#define bmBIT9    0x0200
#define bmBIT10   0x0400
#define bmBIT11   0x0800
#define bmBIT12   0x1000
#define bmBIT13   0x2000
#define bmBIT14   0x4000
#define bmBIT15   0x8000

/*! \endcond */ // NEVER
//-----------------------------------------


//! \brief nombre maximum de voies gres par une station, quel que soit le type de voie
#ifdef DOXYGEN
#define MAX_VOIES 32
#endif

// dfinitions des bits utilises pour masquer les options disponibles (valider ou non)
// dans le paramtre mode des fonctions d'entre SCAN() exemple:AINSCAN et DINSCAN 

//! \brief Flag de mode : Si (mode & DT_AD_ENTREE) => mode bipolaire, sinon monopolaire
#define DT_AD_ENTREE	bmBIT15

//! \brief Flag de mode : Si (mode & DT_AD_VOIE) => mesure diffrentielle, sinon mesure simple\n Note : une mesure en diffrentielle ncessite l'usage de voies par couple.\n Pour l'appariement des voies, se rfrer  la documentation technique de la station.
#define DT_AD_VOIE		bmBIT14

/*! \cond USE_FLAG_AD_BUFF */
//! \brief Flag de mode : Si (mode & DT_AD_BUFF) => mode \ref concept_asynchrone "asynchrone" sinon, mode \ref concept_asynchrone "synchrone"
#define DT_AD_BUFF		bmBIT13
/*! \endcond */


/*! \cond USE_FLAG_AD_CPT */
//! \brief Flag de mode : Si (mode & DT_AD_CPT) => derniere voie d'entre analogique en compteur
#define DT_AD_CPT		bmBIT12
/*! \endcond */ // USE_FLAG_AD_CPT

/*! \cond USE_FLAG_AD_TRGA */
//! \brief Flag de mode : Si (mode & DT_AD_TRGAH) => \ref concept_trigger "dclenchement" sur entre analogique lorsque val > seuil
#define DT_AD_TRGAH		bmBIT9

//! \brief Flag de mode : Si (mode & DT_AD_TRGAB) => \ref concept_trigger "dclenchement" sur entre analogique lorsque val < seuil
#define DT_AD_TRGAB		bmBIT8
/*! \endcond */

/*! \cond USE_FLAG_IRQ */
//! \brief Flag de mode : Si (mode & DT_AD_IRQ) => \ref concept_trigger "dclenchement" sur top interruption
#define DT_AD_IRQ		bmBIT6
/*! \endcond */

/*! \cond USE_FLAG_AD_EXT */
//! \brief Flag de mode : Si (mode & DT_AD_EXT) => \ref concept_trigger "dclenchement" sur signal externe
#define DT_AD_EXT		bmBIT5
/*! \endcond */

/*! \cond USE_FLAG_AD_TIM */
//! \brief Flag de mode : Si (mode & DT_AD_TIM) => frquence d'chantillonnage par gnrateur timer
#define DT_AD_TIM		bmBIT4
/*! \endcond */

/*! \cond USE_FLAG_AD_TRGI */
//! \brief Flag de mode : Si (mode & DT_AD_TRGIH) => \ref concept_trigger "dclenchement" sur entre digital front montant 
#define DT_AD_TRGIH		bmBIT3

//! \brief Flag de mode : Si (mode & DT_AD_TRGIB) => \ref concept_trigger "dclenchement" sur entre digital front descendant
#define DT_AD_TRGIB		bmBIT2
/*! \endcond */

/*! \cond USE_FLAG_AD_TRGO */
//! \brief Flag de mode : Si (mode & DT_AD_TRGOH) => FIXDOC
// Si prsent, \ref concept_trigger "dclenchement"  sur sortie tat haut pour paquet d'acquisition
#define DT_AD_TRGOH		bmBIT1

//! \brief Flag de mode : Si (mode & DT_AD_TRGOB) => FIXDOC
// Si prsent, \ref concept_trigger "dclenchement" sur sortie tat bas pour paquet d'acquisition
#define DT_AD_TRGOB		bmBIT0
/*! \endcond */



//-------------------------------
//! \cond NEVER
//
//Pour compatibilt digitool.h
#define DT_AD_MONO		DT_AD_ENTREE
#define DT_AD_SIMP		DT_AD_VOIE


// dfinitions des bits utilises pour masquer les options disponibles (valider ou non)
// dans le paramtre mode des fonctions de sortie SCAN() exemple:AOUTSCAN et DOUTSCAN 
#define DT_DA_MONO		bmBIT15
#define DT_DA_SIMP		bmBIT14

#define DT_DA_TRGAH		bmBIT9	// 0=inactif, 1=trigger de sortie analogique front montant pour paquet d'acq
#define DT_DA_TRGAB		bmBIT8	// 0=inactif, 1=trigger de sortie analogique front descendant pour paquet d'acq

#define DT_DA_IRQ		bmBIT6
#define DT_DA_EXT		bmBIT5
#define DT_DA_TIM		bmBIT4
#define DT_DA_TRGIH		bmBIT3
#define DT_DA_TRGIB		bmBIT2
#define DT_DA_TRGOH		bmBIT1
#define DT_DA_TRGOB		bmBIT0


/*! \endcond */ // NEVER
//-------------------------------




//---------------------------------
//! \cond USE_SIGNAL_GENERATORS

// dfinitions des bits utilises pour masquer les options disponibles (valider ou non)
// dans le paramtre mode des fonctions generateur de signal GS_init() et Gs_stop()

//! \brief Niveau d'entree
/** Selon :
		- 0: \ref sect_polarite "monopolaire"
		- 1: \ref sect_polarite "bipolaire"

*/
#define DT_GS_ENTREE	bmBIT15

//! \brief Ecriture freq et phase
/** Selon :
    - 0: devalide
	- 1: valide
*/
#define DT_GS_WR    	bmBIT5

//! \brief Registre phase adder 0 ou 1 utilis
#define DT_GS_REG_PHASE bmBIT4

//! \brief Registre phase 0 ou 1 utilis
#define DT_GS_REG_FREQ  bmBIT3

//! \brief Generateur de signal TRIANGLE
#define DT_GS_TRIANGLE	bmBIT2

//! \brief Generateur de signal carre
#define DT_GS_CARRE	    bmBIT1

//! \brief Generateur de signal sinus
#define DT_GS_SINUS	    bmBIT0


/*! \endcond */ // USE_SIGNAL_GENERATORS
//---------------------------------


//---------------------------------
//! \cond USE_POT

//---------------------------------
//! \brief Modes disponibles pour la fonction #Calibrage_An()
enum CALIBRAGE_MODE
{
	DT_CAL_CDE_DEF		= 0x0001,    //!< Restauration d'un calibrage (ne permet que CALIBRAGE_ACTION parmi #DT_CAL_ACT_USINE ou #DT_CAL_ACT_SAUV)
	DT_CAL_CDE_CAL		= 0x0004,    //!< Appliquer un calibrage utilisateur (ne permet que CALIBRAGE_ACTION parmi #DT_CAL_ACT_SAUV ou #DT_CAL_ACT_USER)
};

//! \brief Actions disponibles pour la fonction #Calibrage_An()
enum CALIBRAGE_ACTION
{
	DT_CAL_ACT_USINE	= 0x0000,    //!< Permis qu'avec #DT_CAL_CDE_DEF : restaurer le caibrage usine
	DT_CAL_ACT_SAUV		= 0X0001,    //!< Avec #DT_CAL_CDE_DEF : restaurer le calibrage utilisateur prcdement sauvegards\n Avec #DT_CAL_CDE_CAL : appliquer le calibrage et le sauvegarder en tant que calibrage utilisateur
	DT_CAL_ACT_USER		= 0X0002,    //!< Permis qu'avec #DT_CAL_CDE_CAL : appliquer le calibrage sans le sauvegarder
};

/*! \endcond */ // USE_POT
//---------------------------------







//***********************************************************************
//|||||||||||||||||||||||||||||
// 
//  CE QUI SUIT N'EST PAS UTILISE PAR 
//  LES CARTES ACTUELLES (2011) 
//  ET EST DONC EXCLUS DE LA DOCUMENTATION
//
//! \cond NEVER

// dfinitions des commandes utilises dans les fonctions Read_Pot() Write_Pot() et Calibrage_An()
// Commandes masquee avec l'adresse ADDR 4 bits faibles ou bit A0 
// Exemple DT_POT_S_TO_M_CDE3 | 0x0003 => criture memoire EEMEM adresse 3

#define DT_POT_S_TO_M	0x0030	/* Commande 3: ecriture serial -> EEMEM(ADDR)*/
#define DT_POT_S_TO_R	0x00B0	/* Commande 11: ecriture serial -> RDAC(A0)*/
#define DT_POT_M_TO_S	0x0090	/* Commande 9: ecriture EEMEM(ADDR) -> serial avant lecture*/
#define DT_POT_R_TO_S	0x00A0	/* Commande 10: ecriture RDAC(A0) -> serial pour lecture*/
#define DT_POT_INC		0x00E0	/* Commande 14: ecriture increment +1 RDAC(A0)*/
#define DT_POT_DEC		0x0060	/* Commande 6: ecriture decrement -1 RDAC(A0)*/
#define DT_POT_RESET	0x0080	/* Commande 8: RESET  EEMM0/1 dans RDAC0/1*/
#define DT_POT_SAVE		0x0020	/* Commande 2 : SAVE position RDAC(A0) -> EEMEM(A0)*/
#define DT_POT_NOP		0x0000	/* Commande 0: NOP  + minimum power,Utilise pour lecture aprs CDE 9 et 10*/



//////////////////////////////////////////////////////////
//		Dfinition des bits du paramtre no_composant
///////////////////////////////////////////////
// dfinitions des bits utilises pour masquer les options disponibles (valider ou non)
// dans le paramtre mode des fonctions d'entre et sortie TOR SCAN() exemple:DOUTSCAN et DINSCAN 

#define DT_TOR_TIM	    bmBIT4 /* 0=inactif, 1=frquence d'chantillonnage par generateur timer interne*/
#define DT_TOR_TRGIH	bmBIT3 /* 0=inactif, 1=trigger d'entre front montant pour paquet d'acquisition */
#define DT_TOR_TRGIB    bmBIT2 /* 0=inactif, 1=trigger d'entre front descendant pour paquet d'acquisition*/
#define DT_TOR_TRGOH	bmBIT1 /* 0=inactif, 1=trigger en sortie tat haut pour paquet d'acquisition */
#define DT_TOE_TRGOB	bmBIT0 /* 0=inactif, 1=trigger en sortie tat bas pour paquet d'acquisition */

//Pour les fonctions gnrateur Ginit, Gstart, Gstop
#define DT_TIM_G32B		0X0008	// masque gnrateur 32 bits valid
#define DT_TIM_G16B		0X0000	// masque gnrateur 16 bits valid
#define DT_TIM_MOD0		0X0000	// mode 0 slect top type interruption
#define DT_TIM_MOD1		0X0000	// mode 1 non disponible
#define DT_TIM_MOD2		0X0002	// mode 2 slect rapport cycique 1/freq
#define DT_TIM_MOD3		0X0003	// mode 3 slect rapport cycique 1/2
#define DT_TIM_MOD		bmBIT1 | bmBIT1 	// masque parametre mode  

//
// no_composant pour fonctions timer generateur Gxxxx
//
#define DT_TIM_CPT0B	0X0000	// masque du numro du compteur interne
#define DT_TIM_CPT1B	0X0100	// 16 bits bas d'un timer
#define DT_TIM_CPT2B	0X0200	// 3 compteurs internes dfinis

#define DT_TIM_CPT0H	0X0000	// masque du numro du compteur interne
#define DT_TIM_CPT1H	0X1000	// 16 bits haut d'un timer
#define DT_TIM_CPT2H	0X2000	// 3 compteurs internes dfinis

#define DT_TIM_TIM0B	0X0000	// masque du numro timer correspondant
#define DT_TIM_TIM1B	0X0001	// au compteur 16 bits bas utilis
#define DT_TIM_TIM2B	0X0002	// 8 timers par carte dfinis
#define DT_TIM_TIM3B	0X0003
#define DT_TIM_TIM4B	0X0004
#define DT_TIM_TIM5B	0X0005
#define DT_TIM_TIM6B	0X0006
#define DT_TIM_TIM7B	0X0007

#define DT_TIM_TIM0H	0X0000	// masque du numro timer correspondant
#define DT_TIM_TIM1H	0X0010	// au compteur 16 bits haut utilis
#define DT_TIM_TIM2H	0X0020	// 8 timers par carte dfinis
#define DT_TIM_TIM3H	0X0030
#define DT_TIM_TIM4H	0X0040
#define DT_TIM_TIM5H	0X0050
#define DT_TIM_TIM6H	0X0060
#define DT_TIM_TIM7H	0X0070

/* dfinition des ports logiques */
#define PORTA     0
#define PORTB     1
#define PORTC     2

///////////////////////////////////////////////////
//		Paramtre Status (pour les ITs)
/////////////////////////////////////////
#define DT_AD_INT_ACQUISITION_NON_COMMENCEE		0
#define DT_AD_INT_ACQUISITION_EN_COURS			1
#define DT_AD_INT_ACQUISITION_FINIE				2





//--------------------------------------------------------------------------
// Pour Compatibilit avec le DOS
#define inportb		inp
#define outportb	outp
#define outportw	outpw
#define inportw		inpw
#define inport		inp
#define outport		outp


//--------------------------------------------------------------------------
// FIXME : qu'est ce ?
#define DT_MESS_TRIGGER_ON    1000    /* message trigger  ON	 	*/
#define DT_MESS_TRIGGER_OFF   1001    /* message trigger  OFF	 	*/


//|||||||||||||||||||||||||||||
/*! \endcond */ // NEVER
//|||||||||||||||||||||||||||||




//##########################################################################
/*! @}*/ // Fin de Enum_Constants_Group
//##########################################################################






//##########################################################################
/*! @}*/ // Fin de API_group
//##########################################################################


//+++++++++++++++++++++++++++++++++++++++++++++++
#endif // DIGITOOL_H
