/*
 * DigiTool_Usb.h
 * 
 * Copyright (c) 2011, Digimetrie. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301  USA
 */

#ifndef DIGITOOL_USB_H
#define DIGITOOL_USB_H
//+++++++++++++++++++++++++++++++++++++++++++++++

#include "DigiTool.h"

//--------------------------------------------------------------------------
/**
\file Digitool_Usb.h
API spcifiques aux cartes USB de Digimtrie.
*/

//////////////////////////////////////////////////////////////////////////////////////////////////////////
//		IO bas-niveau USB gestion reseau
//////////////////////////////////////////////////////////////////////////////////////////////////////////

//---------------------------------------------------------------------------------------
//! Cette fonction permet d'effcetuer un reset sur la station USB
C_DECL_START
//-----------
DEXPORT(short)
USB_ResetPort(
				  WORD carte     //!< Nom de la carte (cf. les \#define )
				, WORD adresse	 //!< FIXDOC Adresse de la carte
				);

// Dclaration de prototye de la fonction ci-dessus
//! \cond NEVER
PROTO_DECL(short)
(PASCAL *PROTO_USB_ResetPort)(
						  WORD carte     
						, WORD adresse	 
					);   

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_USB_ResetPort	pf_USB_ResetPort;	
//! \endcond
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Cette fonction permet d'effectuer un reset sur le pipe sur la station USB
// \n      pour unstall du pipe correspondant
C_DECL_START
//-----------
DEXPORT(short)
USB_ResetPipe(
					  WORD pipenum		//!< numero du pipe sur la station 0=EP0 CTL 1=EP2 OUT  2=EP6 IN
					, WORD carte		//!< Nom de la carte (cf. les \#define )
					, WORD adresse		//!< FIXDOC Adresse de la carte
				);  

// Dclaration de prototye de la fonction ci-dessus
//! \cond NEVER
PROTO_DECL(short)
(PASCAL *PROTO_USB_ResetPipe)(
							  WORD pipenum		
							, WORD carte		
							, WORD adresse		
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_USB_ResetPipe	pf_USB_ResetPipe;	
//! \endcond
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//!		Cette fonction permet d'annuler un transfert Pending sur le pipe sur la station USB
/**		
-# [in] Handle valide sur la station
-# [in] numero du pipe sur la station 0=EP2 OUT   1=EP6 IN
*/
C_DECL_START
//-----------
DEXPORT(short)
USB_AbortPipe(
					  WORD pipenum  //!< numero du pipe sur la station 0=EP0 CTL 1=EP2 OUT  2=EP6 IN
					, WORD carte    //!< Nom de la carte (cf. les \#define )
					, WORD adresse  //!< FIXDOC Adresse de la carte
				);

// Dclaration de prototye de la fonction ci-dessus
//! \cond NEVER
PROTO_DECL(short)
(PASCAL *PROTO_USB_AbortPipe)(
							  WORD pipenum  
							, WORD carte    
							, WORD adresse  
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_USB_AbortPipe	pf_USB_AbortPipe;	
//! \endcond
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//!		Cette fonction permet de recuperre le status du dernier transfert URB
/**
-# [in] Handle valide sur la station
-# [in] pointeur sur le status retourne
*/
C_DECL_START
//-----------
DEXPORT(short)
USB_GetUsbLastError(  
						  WORD pipenum			//!< numero du pipe sur la station 0=EP0 CTL 1=EP2 OUT  2=EP6 IN
						, ULONG* purbstatus		//!< retour erreur URB
	                    , char* message			//!< FIXDOC
						, WORD carte			//!< Nom de la carte (cf. les \#define )
						, WORD adresse			//!< FIXDOC Adresse de la carte
					);

// Dclaration de prototye de la fonction ci-dessus
//! \cond NEVER
PROTO_DECL(short)
(PASCAL *PROTO_USB_GetUsbLastError)(
								  WORD pipenum			
								, ULONG* purbstatus		
								, char* message			
								, WORD carte			
								, WORD adresse			
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_USB_GetUsbLastError	pf_USB_GetUsbLastError;	
//! \endcond
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//!		Cette fonction permet de recuperre le nombre de pipe de la station 
//!\n      et la taille maximale d'un paquet 64 octets => FULLSPEED 512 => HIGHTSPEED
/**
-# [in] Handle valide sur la station
-# [in] pointeur sur le status retourne
*/
C_DECL_START
//-----------
DEXPORT(short)
USB_GetPipeInfo(
					  ULONG* pNbOfPipes		//!< nombre de pipe
					, ULONG* pPacketSize	//!< taille maximale d'un paquet
					, WORD carte			//!< Nom de la carte (cf. les \#define )
					, WORD adresse			//!< FIXDOC Adresse de la carte
				);

// Dclaration de prototye de la fonction ci-dessus
//! \cond NEVER
PROTO_DECL(short)
(PASCAL *PROTO_USB_GetPipeInfo)(
							  ULONG* pNbOfPipes		
							, ULONG* pPacketSize	
							, WORD carte			
							, WORD adresse			
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_USB_GetPipeInfo	pf_USB_GetPipeInfo;	
//! \endcond
//-----------
C_DECL_END



//---------------------------------------------------------------------------------------
//!	Permet deconnecter la station et effectuer une renumeration
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
USB_RenumPort( 
					  WORD valeur   // utilisation future
					, WORD carte
					, WORD adresse
				);

// Dclaration de prototye de la fonction ci-dessus
//! \cond NEVER
PROTO_DECL(short)
(PASCAL *PROTO_USB_RenumPort)(
							  WORD valeur   
							, WORD carte
							, WORD adresse
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_USB_RenumPort	pf_USB_RenumPort;	
//! \endcond
//-----------
C_DECL_END


//---------------------------------------------------------------------------------------
//! Remet l'ensemble des peripherique  leur valeur de defaut comme une mise sous tension 
//---------------------------------------------------------------------------------------
C_DECL_START
//-----------
DEXPORT(short)
USB_ResetIo( 
				  WORD valeur	//!< utilisation future
				, WORD carte	//!< FIXDOC
				, WORD adresse	//!< FIXDOC
			);

// Dclaration de prototye de la fonction ci-dessus
//! \cond NEVER
PROTO_DECL(short)
(PASCAL *PROTO_USB_ResetIo)(
							  WORD valeur	
							, WORD carte	
							, WORD adresse	
						);

// Utilise par #Digi_Init_Functions_Pointers() et  auquel cas, dfini dans "DigiTool.c" 
extern PROTO_USB_ResetIo	pf_USB_ResetIo;
//! \endcond
//-----------
C_DECL_END


//-------------------------------------------
//! (R)Initialise les pointeurs de fonctions dfinis dans ce DigiTool_Usb.h
/** 
	 IMPORTANT : Pour pouvoir utiliser cette fonction, il faut inclure DigiTool_Usb.c dans votre Projet.
	 Dans DigiTool_Usb.h, un prototype et un pointeurs de fonction sont associs  chaque fonction exporte par la Dll.
	 Le nom des prototypes sont prfixs par "PROTO_" et le nom des pointeurs par "pf_".
	 Cette fonction initialise tout les pointeur de fonction ainsi dfinis  partir du HMODULE de la Dll pralablement charge.
	 Au retour de la fonction, les pointeurs de fonctions qui n'auront pas pu tre assigns vaudront NULL.

	\param h_loaded_Dll : Le HMODULE rendu par LoadLibrary()
	\param dll_path : Le chemin de la Dll donne  LoadLibrary()

	\return : TRUE si au moins un pointeur de fonction a pu tre initialis
*/
//-------------------------------------------------------------------
DTYPE_C(BOOL)
Digi_Init_Functions_Pointers__USB( HMODULE h_loaded_Dll, P_STR dll_path );



//+++++++++++++++++++++++++++++++++++++++++++++++
#endif // DIGITOOL_USB_H
