/*
 * Digimetrie_Sci.h
 * 
 * Copyright (c) 2011, Digimetrie. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301  USA
 */

/* ==================================================================== */
/* Patrick Negre */
/* DIGIMETRIE 20011 */
/* Declaration d'enveloppeurs autour des fonctions des Dlls Digimetrie */
/* This file is released under the 3-clause BSD license. See COPYING-BSD. */
/* ==================================================================== */
#ifndef __DIGIMETRIE_SCI_H__
#define __DIGIMETRIE_SCI_H__

#define USHORT unsigned short

/**
* ainf_digi function
* @param[in] num_carte : numro de la carte
* @param[in] num_voie : numro de la voie sur la carte
* @param[in] gain     : gain a appliquer aux valeurs lues
* @param[in,out] res : tension lue sur la voie
* @return 0 if no error
*/
int digi_AInf( int num_carte, int num_voie, int gain, float *res );

/**
* ainf_digi function
* @param[in] num_carte : numro de la carte
* @param[in] nb_voies : nombre de voies sur lesquelles faires les acquisitions
* @param[in] gain     : tableau de tailles 16 pour les gains a appliquer sur les voies
* @param[out] arr_res : tableaux des valeurs lues
* @param[in] frequence_hz  : nombre d'acquisitions par secondes
* @param[in] nb_acquisitions  : nombre d'acquisitions  effectuer en tout
* @return 0 if no error
*/
int digi_AInf_Scan(int num_carte, int nb_voies, USHORT arr_gain[], float *arr_res, int frequence_hz, int nb_acquisitions );

/**
* aout_digi function
* @param[in] num_carte : numro de la carte
* @param[in] num_voie : numro de la voie sur la carte
* @param[in] val : tension  fixer pour la voiedigi_bin
* @return 0 if no error
*/
int digi_AOutf(int num_carte, int num_voie, float val );

/**
* aout_digi function
* @param[in] num_carte : numro de la carte
* @param[in] nb_voies : nombre de voies sur lesquelles faires les restitutions
* @param[in] arr_val : tableau des valeurs  restituer
* @param[in] nb_restitutions : nombre de restitution en tout
* @param[in] frequence_hz : nombre de restitutions par seconde
* @return 0 if no error
*/
int
digi_AOutf_Scan(int num_carte, int nb_voies, float* arr_val, int nb_restitutions, int frequence_hz );

/**
* din_digi function
* @param[in] num_carte : numro de la carte
* @param[in] num_voie : numro de la voie sur la carte
* @param[out] res : tat lu des voies digitales
* @return 0 if no error
*/
int digi_DIn(int num_carte, int num_voie, int *res );

/**
* bin_digi function
* @param[in] num_carte : numro de la carte
* @param[in] num_voie : numro de la voie sur la carte
* @param[in] num_ligne : numro de la carte
* @param[out] res : tat lu sur la ligne (0 ou 1)
* @return 0 if no error
*/
int digi_BIn(int num_carte, int num_voie, int num_ligne, int *res );

/**
* dout_digi function
* @param[in] num_carte : numro de la carte 
* @param[in] num_voie : numro de la voie sur la carte
* @param[in] val : tat  fixer pour les voies
* @return 0 if no error
*/
int digi_DOut(int num_carte, int num_voie, int val );

/**
* dout_digi function
* @param[in] num_carte : numro de la carte 
* @param[in] num_voie : numro de la voie sur la carte
* @param[in] num_ligne : numro de la ligne
* @param[in] val : valeur  fixer pour la ligne
* @return 0 if no error
*/
int digi_BOut(int num_carte, int num_voie, int num_ligne, int val );


/**
	Retourne la chaine de caractre dcrivant l'erreur donne en paramtre
*/
const char* digi_get_Error_String( int err_num );


/* ==================================================================== */
/*! Fonction multi-usages pour tester|parametrer un carte Digimtrie
/**
 Arguments :
   num_carte : Numero de la carte
   num_voie  : TypeNumero de la voie
   typeTest  : Type de test

  Si "Type de test" :
		== 0 : Test que la carte existe
		== 1 : Paramtre la voie spcifie en AIN
		== 2 : Paramtre la voie spcifie en AOUT
		== 3 : Paramtre la voie spcifie en DIN
		== 4 : Paramtre la voie spcifie en DOUT

 Retourne :
			1 si tout est ok (le test|paramtrage a russi)
			0 si erreur pendant le test|paramtrage
*/
int digi_TestParam( int num_carte, int num_voie, int typeTest );


/* ==================================================================== */
/*! Fonction permettant de rinitiser le pont Scilab - cartes Digimtries */
/*
	Les cartes et oprations en cours sont annules.
	La procdure de recherche de cartes digimtrie est relances.
	Les cartes prsentes seront rinitialises  leur prochaine opration.
	
	\return : <  0  ==>>  (-1)xError_Code : Code d'erreur rapport par l'initialisation (note: il faudra redresser le signe)
	\return : >= 0  ==>>  Le nombre de cartes digimtries trouves sur le systme.
*/
int digi_Reinit();


#endif /* __DIGIMETRIE_SCI_H__ */

